import { defineConfig } from 'vitepress'

// https://vitepress.dev/reference/site-config
export default defineConfig({
  title: "Bluefly Documentation",
  description: "Documentation for Bluefly's LLM Platform",
  base: process.env.VITEPRESS_BASE_URL || '/',
  lastUpdated: true,
  cleanUrls: true,
  
  head: [
    ['link', { rel: 'icon', href: '/favicon.ico' }],
    ['meta', { name: 'theme-color', content: '#3eaf7c' }],
    ['meta', { name: 'og:type', content: 'website' }],
    ['meta', { name: 'og:site_name', content: 'Bluefly Documentation' }]
  ],

  themeConfig: {
    // https://vitepress.dev/reference/default-theme-config
    logo: '/logo.svg',
    siteTitle: 'Bluefly Docs',

    nav: [
      { text: 'Home', link: '/' },
      { text: 'User Guide', link: '/user/' },
      { text: 'Technical', link: '/technical/' },
      { text: 'API', link: '/api/' },
      { text: 'Components', link: '/components/' },
      {
        text: 'Resources',
        items: [
          { text: 'Getting Started', link: '/getting-started' },
          { text: 'Best Practices', link: '/best-practices' },
          { text: 'Examples', link: '/examples' }
        ]
      }
    ],

    sidebar: {
      '/user/': [
        {
          text: 'User Guide',
          items: [
            { text: 'Getting Started', link: '/user/getting-started' },
            { text: 'Monitoring', link: '/user/monitoring' },
            { text: 'Configuration', link: '/user/configuration' }
          ]
        }
      ],
      '/technical/': [
        {
          text: 'Technical Documentation',
          items: [
            { text: 'Architecture', link: '/technical/architecture' },
            { text: 'Monitoring', link: '/technical/monitoring' },
            { text: 'API Reference', link: '/technical/api-reference' }
          ]
        }
      ],
      '/components/': [
        {
          text: 'Components',
          items: [
            { text: 'llmcli', link: '/components/llmcli/' },
            { text: 'Monitoring', link: '/components/llmcli/monitoring' }
          ]
        }
      ]
    },

    socialLinks: [
      { icon: 'gitlab', link: 'https://gitlab.bluefly.io/blueflyio/internal-projects/llm/llmcli' }
    ],

    search: {
      provider: 'local',
      options: {
        detailedView: true,
        miniSearch: {
          searchOptions: {
            fuzzy: 0.2,
            prefix: true,
            boost: {
              title: 4,
              text: 2,
              titles: 1
            }
          }
        }
      }
    },

    editLink: {
      pattern: 'https://gitlab.bluefly.io/blueflyio/internal-projects/llm/bfdocs/-/edit/main/docs/:path',
      text: 'Edit this page on GitLab'
    },

    footer: {
      message: 'Released under the MIT License.',
      copyright: `Copyright © ${new Date().getFullYear()} Bluefly`
    },

    // New VitePress 1.0 features
    outline: {
      level: [2, 3],
      label: 'On this page'
    },

    lastUpdated: {
      text: 'Updated at',
      formatOptions: {
        dateStyle: 'full',
        timeStyle: 'medium'
      }
    },

    docFooter: {
      prev: 'Previous page',
      next: 'Next page'
    },

    darkMode: true,
    
    // GitLab integration
    externalLinkIcon: true,
    returnToTopLabel: 'Return to top',
    
    // Performance optimizations
    cacheDir: '.vitepress/cache',
    ignoreDeadLinks: true,
  },

  // Build optimizations
  vite: {
    build: {
      chunkSizeWarningLimit: 1000,
      rollupOptions: {
        output: {
          manualChunks: {
            'search': ['./VPAlgoliaSearchBox.vue'],
            'vue': ['vue', 'vue-router'],
          }
        }
      }
    },
    ssr: {
      noExternal: ['vitepress-plugin-tabs']
    }
  },

  // Markdown config
  markdown: {
    theme: {
      light: 'github-light',
      dark: 'github-dark'
    },
    lineNumbers: true,
    anchor: {
      permalink: true,
      permalinkBefore: true,
      permalinkSymbol: '#'
    },
    toc: { level: [2, 3] },
    config: (md) => {
      // Add custom markdown-it plugins here
    }
  }
}) 