import { h } from 'vue'
import Theme from 'vitepress/theme'
import { useRoute } from 'vitepress'
import DefaultTheme from 'vitepress/theme'
import { TabsPlugin } from 'vitepress-plugin-tabs'
import mermaid from 'vitepress-plugin-mermaid'
import giscusTalk from '@giscus/vue'
import './custom.css'

// Custom components
import ApiEndpoint from './components/ApiEndpoint.vue'
import CodeGroup from './components/CodeGroup.vue'
import CodeBlock from './components/CodeBlock.vue'
import Badge from './components/Badge.vue'

export default {
  extends: DefaultTheme,
  enhanceApp({ app }) {
    // Register custom components
    app.component('ApiEndpoint', ApiEndpoint)
    app.component('CodeGroup', CodeGroup)
    app.component('CodeBlock', CodeBlock)
    app.component('Badge', Badge)
    
    // Register plugins
    app.use(TabsPlugin)
    app.use(mermaid)
    
    // Register Giscus for comments
    app.component('Comments', giscusTalk, {
      repo: 'blueflyio/bfdocs',
      repoId: 'R_kgDOGvqE5Q',
      category: 'Comments',
      categoryId: 'DIC_kwDOGvqE5c4CQoKp',
      mapping: 'pathname',
      inputPosition: 'top',
      lang: 'en',
      theme: 'preferred_color_scheme'
    })
  },
  
  setup() {
    // Custom setup logic
    const route = useRoute()
    
    // Add custom meta tags
    if (typeof document !== 'undefined') {
      const meta = document.createElement('meta')
      meta.name = 'docsearch:language'
      meta.content = 'en'
      document.head.appendChild(meta)
    }
  },
  
  // Layout slots
  Layout() {
    return h(Theme.Layout, null, {
      // Add custom layout slots here
      'doc-before': () => h('div', { class: 'custom-doc-before' }),
      'doc-after': () => h('div', { class: 'custom-doc-after' }, [
        h('Comments')
      ])
    })
  }
} 