# Drupal Native AI to LLM Module Migration Plan

## Executive Summary
This plan outlines the systematic migration of drupal_native_ai functionality into the llm module ecosystem, preserving all critical features while eliminating redundancy and improving integration.

## 1. Services to Move to Main LLM Module

### Core Services (Move to `Drupal\llm\Service\AI\Core`)
- **NativeAIService** → `Drupal\llm\Service\AI\Core\NativeAiService` (already exists)
- **ModelRegistry** → Merge with existing `Drupal\llm\Service\ModelRegistryService`
- **ContentAnalyzerService** → `Drupal\llm\Service\AI\Core\ContentAnalyzerService`
- **EntityProcessor** → `Drupal\llm\Service\AI\Core\EntityProcessor`
- **EmbeddingManager** → Merge with `Drupal\llm\Service\AI\Core\VectorService`

### Integration Services (Move to `Drupal\llm\Service\AI\Integration`)
- **LlmPlatformIntegration** → Already covered by existing platform services
- **NativeAIVectorIntegration** → Merge with `Drupal\llm\Service\AI\Core\VectorService`
- **NeuralMemoryIntegration** → Merge with `Drupal\llm\Service\NeuralMemoryService`

### Bridge Services (Move to `Drupal\llm\Service\Bridge`)
- **McpIntegrationService** → `Drupal\llm\Service\Bridge\McpBridgeService`
- **NeuroSymbolicService** → `Drupal\llm\Service\Bridge\NeuroSymbolicBridgeService`

## 2. Services to Become LLM Submodules

### llm_benchmark (Model Comparison & Benchmarking)
```
modules/custom/llm/modules/llm_benchmark/
├── llm_benchmark.info.yml
├── llm_benchmark.services.yml
└── src/
    ├── Controller/
    │   └── ModelComparisonController.php
    ├── Form/
    │   └── ModelManagementForm.php
    └── Service/
        └── ModelBenchmarkService.php (enhanced from existing)
```

### llm_streaming (Real-time Streaming Support)
```
modules/custom/llm/modules/llm_streaming/
├── llm_streaming.info.yml
├── llm_streaming.services.yml
└── src/
    ├── Service/
    │   └── StreamingService.php
    └── EventSubscriber/
        └── StreamingEventSubscriber.php
```

### llm_content_analysis (Content Analysis & Enhancement)
```
modules/custom/llm/modules/llm_content_analysis/
├── llm_content_analysis.info.yml
├── llm_content_analysis.services.yml
└── src/
    ├── Controller/
    │   ├── ContentAnalyticsController.php
    │   └── ContentAnalyzerController.php
    ├── Form/
    │   ├── ContentAnalysisForm.php
    │   └── BatchAnalysisForm.php
    ├── Plugin/
    │   ├── Field/
    │   │   ├── FieldType/
    │   │   │   ├── AIEnhancedTextField.php
    │   │   │   └── ContentAnalysisScoreItem.php
    │   │   ├── FieldWidget/
    │   │   │   ├── AIEnhancedTextWidget.php
    │   │   │   └── ContentAnalysisScoreWidget.php
    │   │   └── FieldFormatter/
    │   │       ├── AIEnhancedTextFormatter.php
    │   │       └── ContentAnalysisScoreFormatter.php
    │   └── Block/
    │       └── ContentAnalysisStatsBlock.php
    └── Service/
        ├── ContentAnalyzerService.php
        └── BatchProcessor.php
```

### llm_neural_memory (Neural Memory & Learning)
```
modules/custom/llm/modules/llm_neural_memory/
├── llm_neural_memory.info.yml
├── llm_neural_memory.services.yml
└── src/
    ├── Controller/
    │   ├── NeuralMemoryController.php
    │   └── MemoryAnalyticsController.php
    ├── Form/
    │   └── NeuralMemoryForm.php
    ├── Service/
    │   ├── NeuralMemoryService.php (enhanced)
    │   ├── MemoryGraphAnalyzer.php
    │   └── MemoryOrchestrator.php
    └── Event/
        └── NeuralMemoryEvent.php
```

### llm_native_bridge (Native AI.js Bridge)
```
modules/custom/llm/modules/llm_native_bridge/
├── llm_native_bridge.info.yml
├── llm_native_bridge.services.yml
├── js/
│   └── native-ai-bridge.js
└── src/
    ├── Controller/
    │   └── NativeAIAPIController.php
    └── Service/
        └── JsSettingsManager.php
```

### llm_eca_integration (ECA Integration)
```
modules/custom/llm/modules/llm_eca_integration/
├── llm_eca_integration.info.yml
├── llm_eca_integration.services.yml
└── src/
    ├── Plugin/
    │   ├── ECA/
    │   │   ├── Action/
    │   │   │   ├── AnalyzeContent.php
    │   │   │   └── ApplyContentEnhancements.php
    │   │   ├── Condition/
    │   │   │   └── ContentAnalysisCondition.php
    │   │   └── Event/
    │   │       ├── ContentAnalysisEvents.php
    │   │       └── ContentAnalysisEventsDeriver.php
    │   └── FieldEcaBridge/
    │       └── AIEnhancedTextField.php
    └── Adapter/
        └── EcaAdapter.php
```

## 3. Namespace Mapping

### Primary Namespace Changes
```php
// Old namespace
Drupal\drupal_native_ai\*

// New namespaces
Drupal\llm\*                           // Core functionality
Drupal\llm_benchmark\*                 // Benchmarking submodule
Drupal\llm_streaming\*                 // Streaming submodule
Drupal\llm_content_analysis\*          // Content analysis submodule
Drupal\llm_neural_memory\*             // Neural memory submodule
Drupal\llm_native_bridge\*             // Native bridge submodule
Drupal\llm_eca_integration\*           // ECA integration submodule
```

### Detailed Namespace Mapping
```php
// Services
Drupal\drupal_native_ai\Service\NativeAIService → Drupal\llm\Service\AI\Core\NativeAiService
Drupal\drupal_native_ai\Service\ModelRegistry → Drupal\llm\Service\ModelRegistryService
Drupal\drupal_native_ai\Service\ContentAnalyzerService → Drupal\llm_content_analysis\Service\ContentAnalyzerService
Drupal\drupal_native_ai\Service\EmbeddingManager → Drupal\llm\Service\AI\Core\VectorService
Drupal\drupal_native_ai\Service\EntityProcessor → Drupal\llm\Service\AI\Core\EntityProcessor
Drupal\drupal_native_ai\Service\NeuralMemoryService → Drupal\llm_neural_memory\Service\NeuralMemoryService
Drupal\drupal_native_ai\Service\BatchProcessor → Drupal\llm_content_analysis\Service\BatchProcessor
Drupal\drupal_native_ai\Service\MemoryGraphAnalyzer → Drupal\llm_neural_memory\Service\MemoryGraphAnalyzer
Drupal\drupal_native_ai\Service\MemoryOrchestrator → Drupal\llm_neural_memory\Service\MemoryOrchestrator

// Controllers
Drupal\drupal_native_ai\Controller\ModelComparisonController → Drupal\llm_benchmark\Controller\ModelComparisonController
Drupal\drupal_native_ai\Controller\ContentAnalyticsController → Drupal\llm_content_analysis\Controller\ContentAnalyticsController
Drupal\drupal_native_ai\Controller\NeuralMemoryController → Drupal\llm_neural_memory\Controller\NeuralMemoryController
Drupal\drupal_native_ai\Controller\NativeAIAPIController → Drupal\llm_native_bridge\Controller\NativeAIAPIController

// Plugins
Drupal\drupal_native_ai\Plugin\AIProvider\NativeAIProvider → Drupal\llm\Plugin\AIProvider\NativeAIProvider
Drupal\drupal_native_ai\Plugin\Field\* → Drupal\llm_content_analysis\Plugin\Field\*
Drupal\drupal_native_ai\Plugin\ECA\* → Drupal\llm_eca_integration\Plugin\ECA\*
```

## 4. Duplicate Functionality Consolidation

### Model Registry
- **Current**: Both modules have model registry services
- **Action**: Merge drupal_native_ai's model comparison features into llm's ModelRegistryService
- **Enhancement**: Add benchmarking capabilities to unified service

### Vector/Embedding Management
- **Current**: drupal_native_ai has EmbeddingManager, llm has VectorService
- **Action**: Merge EmbeddingManager functionality into VectorService
- **Enhancement**: Unified vector operations with multiple backend support

### Neural Memory
- **Current**: Both modules have neural memory concepts
- **Action**: Merge into enhanced NeuralMemoryService in llm_neural_memory submodule
- **Enhancement**: Add graph analysis and pattern learning

### Provider Detection
- **Current**: drupal_native_ai has provider detection
- **Action**: Integrate with llm's existing provider system
- **Enhancement**: Auto-detection of available providers

### Batch Processing
- **Current**: Both modules have queue/batch capabilities
- **Action**: Use llm's existing queue infrastructure
- **Enhancement**: Add specialized content analysis queue workers

## 5. Directory Structure for Merged Code

```
modules/custom/llm/
├── llm.info.yml
├── llm.services.yml
├── src/
│   ├── Service/
│   │   ├── AI/
│   │   │   ├── Core/
│   │   │   │   ├── NativeAiService.php (enhanced)
│   │   │   │   ├── VectorService.php (enhanced with embedding)
│   │   │   │   ├── EntityProcessor.php (new)
│   │   │   │   └── ContentAnalyzerService.php (moved to submodule)
│   │   │   └── Integration/
│   │   │       └── ProviderDetectionService.php (new)
│   │   ├── Bridge/
│   │   │   ├── McpBridgeService.php (new)
│   │   │   └── NeuroSymbolicBridgeService.php (new)
│   │   └── ModelRegistryService.php (enhanced)
│   ├── Plugin/
│   │   └── AIProvider/
│   │       └── NativeAIProvider.php (moved)
│   └── Adapter/
│       ├── NativeAIAdapterInterface.php
│       ├── NativeAIAdapterBase.php
│       ├── NativeAIAdapterManager.php
│       └── LlmPlatformAdapter.php
├── modules/
│   ├── llm_benchmark/
│   ├── llm_streaming/
│   ├── llm_content_analysis/
│   ├── llm_neural_memory/
│   ├── llm_native_bridge/
│   └── llm_eca_integration/
├── js/
│   └── native-ai-integration.js
└── css/
    ├── native-ai-admin.css
    └── native-ai-field-widget.css
```

## 6. Migration Steps

### Phase 1: Preparation (Week 1)
1. Create submodule directories
2. Set up service definitions
3. Create namespace aliases for backward compatibility

### Phase 2: Core Service Migration (Week 2)
1. Move and refactor NativeAIService
2. Merge ModelRegistry functionality
3. Integrate VectorService with EmbeddingManager
4. Move EntityProcessor

### Phase 3: Submodule Creation (Week 3-4)
1. Create llm_benchmark with model comparison
2. Create llm_content_analysis with all content features
3. Create llm_neural_memory with memory features
4. Create llm_native_bridge for JS integration
5. Create llm_eca_integration for ECA support

### Phase 4: Integration & Testing (Week 5)
1. Update all service references
2. Test provider detection integration
3. Verify streaming functionality
4. Test native AI.js bridge
5. Validate ECA integration

### Phase 5: Cleanup & Documentation (Week 6)
1. Remove deprecated code
2. Update documentation
3. Create migration guide
4. Update examples

## 7. Key Benefits

1. **Modularity**: Features organized into optional submodules
2. **No Duplication**: Unified services for common functionality
3. **Better Integration**: Leverages existing llm infrastructure
4. **Maintainability**: Clear separation of concerns
5. **Backward Compatibility**: Namespace aliases during transition
6. **Performance**: Reduced overhead from duplicate services

## 8. Risk Mitigation

1. **Service Dependencies**: Map all dependencies before migration
2. **Database Schema**: Ensure compatible schema migration
3. **Configuration**: Migrate settings appropriately
4. **Custom Code**: Provide clear upgrade path for custom implementations
5. **Testing**: Comprehensive test coverage for all migrated features

## 9. Success Criteria

- All drupal_native_ai features available in llm ecosystem
- No functionality regression
- Improved performance metrics
- Clear documentation for developers
- Successful migration of existing installations