# Golden Standard Documentation Template

## Purpose

This template establishes the golden standard for all LLM Platform documentation. Every module, service, and component should follow this structure to clearly explain:

1. **Why This Exists** - What gap it fills vs existing solutions
2. **Integration with Open Source** - How it enhances rather than duplicates
3. **Unique Value Proposition** - What makes it different and necessary
4. **Technical Differentiation** - Specific technical advantages

## Template Structure

### Module/Service Name

**One-line description that clearly states the unique purpose**

#### Why This Exists Instead of Using [Existing Solution]

- **Problem with existing solutions**: Specific technical limitations or gaps
- **Our unique approach**: How we solve it differently/better
- **Integration strategy**: How we enhance rather than replace

#### Open Source Integration

- **Built on top of**: List of open source projects we extend
- **Contributes back**: How we give back to the ecosystem
- **Standards compliance**: Which standards we follow (OpenAPI, Drupal, etc.)

#### Technical Differentiation

- **Architecture advantages**: Specific technical benefits
- **Performance improvements**: Measurable gains
- **Security enhancements**: Additional protections
- **Developer experience**: How it's easier to use

#### Integration Points

- **Drupal ecosystem**: How it integrates with contrib modules
- **API standards**: OpenAPI compliance, standardization
- **Service mesh**: How it fits in the broader architecture

#### Contribution to Ecosystem

- **What we add**: New capabilities not available elsewhere
- **What we enhance**: Existing tools we make better
- **What we standardize**: Common patterns we establish

## Example Applications

### Example 1: bfllm Service

**AI model inference service optimized for Drupal ecosystem integration**

#### Why This Exists Instead of Using OpenAI API Directly

- **Problem with direct API usage**: No caching, no Drupal entity integration, no role-based access control
- **Our unique approach**: Drupal-native service with entity storage, caching, and permission system
- **Integration strategy**: Works alongside AI module, extends rather than replaces

#### Open Source Integration

- **Built on top of**: Drupal AI module, OpenAPI standards, Docker
- **Contributes back**: AI provider plugins, caching patterns, security modules
- **Standards compliance**: OpenAPI 3.1, PSR-4, Drupal coding standards

#### Technical Differentiation

- **Architecture advantages**: Microservice with Drupal integration, not monolithic
- **Performance improvements**: Redis caching reduces API calls by 80%
- **Security enhancements**: JWT validation, rate limiting, audit logging
- **Developer experience**: Drupal entities instead of raw API responses

### Example 2: mcp_client_extras Module

**MCP protocol client with Drupal workflow integration**

#### Why This Exists Instead of Using Basic MCP Client

- **Problem with basic clients**: No workflow integration, no Drupal permissions, no ECA events
- **Our unique approach**: Native Drupal integration with ECA workflows and entity storage
- **Integration strategy**: Extends MCP protocol with Drupal-specific features

#### Open Source Integration

- **Built on top of**: MCP protocol specification, ECA module, Drupal core
- **Contributes back**: MCP provider plugins, workflow patterns
- **Standards compliance**: MCP protocol, Drupal plugin API

## Implementation Checklist

For each module/service, ensure documentation includes:

- [ ] Clear explanation of why it exists vs alternatives
- [ ] List of open source projects it integrates with
- [ ] Specific technical advantages and measurements
- [ ] How it contributes back to the ecosystem
- [ ] Integration points with existing tools
- [ ] Performance benchmarks where applicable
- [ ] Security considerations and enhancements
- [ ] Developer experience improvements

## Quality Standards

### Language Requirements

- **Professional tone**: No marketing buzzwords or superlatives
- **Technical accuracy**: Specific technical details and measurements
- **Clear differentiation**: Obvious why this is better than alternatives
- **Integration focus**: How it works with existing tools

### Content Requirements

- **Measurable benefits**: Specific performance improvements
- **Real use cases**: Actual problems it solves
- **Technical depth**: Architecture diagrams and code examples
- **Community value**: How it helps the broader ecosystem

### Validation Criteria

- **Would a developer understand why this exists?**
- **Are the technical advantages clear and measurable?**
- **Does it explain integration with existing tools?**
- **Is the unique value proposition obvious?**

## Review Process

1. **Technical Review**: Verify technical claims and benchmarks
2. **Community Review**: Ensure it adds value to ecosystem
3. **Standards Review**: Check compliance with documentation standards
4. **Integration Review**: Verify integration points are accurate

This template ensures every piece of documentation clearly explains why we built something instead of using existing solutions, and how we enhance the ecosystem rather than fragmenting it.