# Drupal AI Platform Implementation Roadmap

Generated from drupal-modules-enhancement-analysis.md on 2025-06-12

## Executive Summary

This roadmap consolidates all enhancement opportunities for the custom modules in `/Users/flux423/Sites/LLM/DEMO/web/modules/custom`. The implementation follows "the Drupal way" - replacing custom logic with native Drupal APIs, Event Subscribers, Plugin systems, Configuration Entities, and Views.

**Key Principle**: Favor [Contrib modules](https://www.drupal.org/project/project_module) over custom implementations when functionality overlaps.

## Phase 1: Secure & Optimize (January 2025)

### Security Enhancements (Priority: CRITICAL)
- [ ] **[SEC-1]** Implement OAuth2/JWT authentication via simple_oauth contrib module
- [ ] **[SEC-2]** Add rate limiting using Drupal flood control API  
- [ ] **[SEC-3]** Enforce RBAC through Drupal permission system
- [ ] **[SEC-4]** Implement audit logging via hook_watchdog or maillog contrib

### Performance Optimizations (Priority: HIGH)
- [ ] **[PERF-1]** Convert to Drupal cache systems (cache_render, cache_data)
- [ ] **[PERF-2]** Add Redis support via redis contrib module
- [ ] **[PERF-3]** Convert blocking calls to queue workers using \Drupal::queue
- [ ] **[PERF-4]** Use views_data_export for heavy exports

### Code Quality (Priority: HIGH)
- [ ] **[CODE-1]** Convert procedural files to PSR-4 class structure
- [ ] **[CODE-2]** Add PHPUnit + Nightwatch.js tests
- [ ] **[CODE-3]** Integrate PHPStan and phpcs

### Architecture Improvements (Priority: HIGH)
- [ ] **[ARCH-1]** Use Dependency Injection in services and controllers
- [ ] **[ARCH-2]** Replace procedural logic with Plugins and Events

## Phase 2: Expand Features (February 2025)

### AI/ML Expansion (Priority: MEDIUM)
- [ ] **[FEAT-1]** Build model plugin types using Drupal Plugin API
- [ ] **[FEAT-2]** Create model entity type or config entity for versioning
- [ ] **[FEAT-3]** Add GraphQL support with graphql contrib
- [ ] **[FEAT-4]** Enhance semantic search with search_api + search_api_vector

### Module-Specific Features

#### LLM Platform Module
- [ ] **[LLM-PLAT-STREAM]** Implement streaming LLM responses (SSE/WebSocket)
- [ ] **[LLM-PLAT-FALLBACK]** Add fallback provider mechanism
- [ ] **[LLM-PLAT-PROMPT-TEMPLATES]** Introduce prompt template library

#### API Normalization Module  
- [ ] **[API-NORM-GRAPHQL]** Add GraphQL support via graphql module
- [ ] **[API-NORM-VERSIONING]** Implement API versioning strategy
- [ ] **[API-NORM-OPENAPI]** Generate OpenAPI docs automatically
- [ ] **[API-NORM-POSTMAN]** Provide Postman collection export

#### Native AI Module
- [ ] **[NATIVE-AI-VECTOR]** Complete vector/embedding support with Milvus
- [ ] **[NATIVE-AI-QUEUE]** Queue training data ingestion
- [ ] **[NATIVE-AI-PROMPT-LIB]** Build prompt template library reuse
- [ ] **[NATIVE-AI-FALLBACK]** Implement fallback AI routes to LLM platform

#### Alternative Services Module
- [ ] **[ALT-SVC-REDIS]** Integrate Redis contrib module for caching backend
- [ ] **[ALT-SVC-ASYNC]** Convert blocking service operations to Queue workers

## Phase 3: Connect & Observe (March 2025)

### Integration Opportunities (Priority: MEDIUM)
- [ ] **[INT-1]** Use EventDispatcher for cross-module orchestration
- [ ] **[INT-2]** Centralize AI model invocation with tagged service 'llm_provider'
- [ ] **[INT-3]** Share Redis cache backend between modules
- [ ] **[INT-4]** Add OpenTelemetry via otel contrib module
- [ ] **[INT-5]** Integrate Llama.cpp via shared REST gateway

### Architecture (Priority: MEDIUM)
- [ ] **[ARCH-3]** Add service container factories for conditional logic

### UI/UX Improvements (Priority: MEDIUM)
- [ ] **[UI-1]** Replace Twig admin pages with Form API
- [ ] **[UI-2]** Implement Single Directory Components (SDCs)
- [ ] **[UI-3]** Add Views dashboards for AI metrics

### Low Priority Items
- [ ] **[UI-4]** Ensure Experience Builder compatibility
- [ ] **[ALT-SVC-GRAFANA]** Add Grafana & Prometheus integration

## Phase 4: Polish & Ship (April 2025)

### Final Testing & Documentation
- Ensure 90% test coverage
- Publish docs to GitLab Pages
- Validate all routes pass OpenAPI schema tests
- Create comprehensive user guides

## Success Metrics

| Area        | Target                                                               |
|-------------|----------------------------------------------------------------------|
| Performance | <200ms API response time, 1000+ RPS sustained                       |
| Security    | 100% authenticated endpoints, zero OWASP Top 10 risks               |
| Coverage    | 95% test coverage, 100% config coverage                             |
| Adoption    | 100+ installations, 90% CLI user satisfaction                       |

## Module-Specific TODO Locations

### Alternative Services (`alternative_services.module`)
- Lines 330-360: Redis integration, async queue workers, Grafana/Prometheus

### API Normalization (`api_normalization.module`)
- Lines 333-377: GraphQL, API versioning, OpenAPI docs, Postman export

### LLM Platform (`llm.module`)
- Lines 101-144: Streaming responses, fallback providers, prompt templates

### Native AI (`native_ai.module`)
- Lines 13-54: Vector support, queue ingestion, prompt library, fallback routes

## Next Steps

1. **Week 1**: Focus on security implementations (OAuth2, rate limiting)
2. **Week 2**: Set up Redis and convert to queue workers
3. **Week 3**: Begin module-specific feature implementations
4. **Week 4**: Integration testing and documentation

## Notes

- All TODOs have been embedded as comments in the respective module files
- Each TODO includes complexity, estimated hours, and due dates
- Focus on replacing custom code with contrib modules where possible
- Prioritize security and performance before new features