# BFCIComponents - Component Library

This directory contains all reusable GitLab CI/CD components for the BlueFly CI Components (BFCIComponents) library. Each component follows a standardized structure and provides a specific piece of functionality that can be included in GitLab CI/CD pipelines.

## Component Organization

Components are organized into categories based on their functionality:

- `api/`: Components for API services
- `llmcli/`: Components for llmcli integration
- `ci/`: Core CI/CD components for various project types
- `claude-autotest/`: Components for AI-powered test generation
- `code-quality/`: Components for code quality analysis
- `docs/`: Components for documentation management
- `drupal/`: Components for Drupal projects
- `gitlab/`: Components for GitLab-specific utilities
- `k8s/`: Components for Kubernetes deployments
- `llm/`: Components for Large Language Model integration
- `model-registry/`: Components for AI model registry
- `monitoring/`: Components for monitoring and observability
- `nodejs/`: Components for Node.js projects
- `php/`: Components for PHP projects
- `shared/`: Shared components that can be used by multiple project types
- `todo-aggregator/`: Components for TODO management and analysis

## Component Structure

Each component follows a standardized structure:

```
components/category/component-name/
├── LICENSE.md                   # MIT License file
├── README.md                    # Component documentation
├── template.yml                 # GitLab CI component template
├── config/                      # Configuration files (optional)
├── scripts/                     # Script files (optional)
└── manifests/                   # Kubernetes manifests (for k8s components)
```

## Component Template Format

Component templates follow the GitLab CI/CD component specification format:

```yaml
# Component Name
#
# Description of the component
#
# Usage:
# include:
#   - component: gitlab.bluefly.io/llm/bfcicomponents/components/category/component-name@main
#     inputs:
#       input1: value1
#       input2: value2

spec:
  inputs:
    input1:
      type: string
      description: "Description of input1"
      default: "default value"
    input2:
      type: number
      description: "Description of input2"
      default: 42

stages:
  - stage1
  - stage2

job1:
  stage: stage1
  script:
    - echo "Job 1"
  variables:
    VARIABLE1: "$input1"
    VARIABLE2: "$input2"

job2:
  stage: stage2
  script:
    - echo "Job 2"
  needs:
    - job1
```

## Component Development

When developing a new component:

1. Create a new directory in the appropriate category
2. Create a template.yml file following the standard format
3. Create a README.md file with detailed documentation
4. Create a LICENSE.md file (MIT License)
5. Add any necessary scripts, configuration files, or other resources
6. Update the component catalog in ci-catalog.yml
7. Test the component using the validation tools

## Golden Components

Golden components are high-level components that combine multiple specialized components to provide a complete CI/CD pipeline for a specific project type. They are located in their respective category directories (e.g., `drupal/drupal_golden_ci_module`).

## Component Catalog

The complete list of available components is maintained in the [ci-catalog.yml](./ci-catalog.yml) file, which is used to publish the components to the GitLab CI/CD Component Catalog.

For a user-friendly component index, see the [Component Index](../docs/COMPONENT_INDEX.md) in the docs directory.