# API Service Component

GitLab CI/CD component for REST API services with OpenAPI validation and comprehensive testing.

## Features

- **OpenAPI Validation**: Automatic validation of API specifications
- **Multi-language Support**: Node.js, PHP, Python, Go API testing
- **Documentation Generation**: Automated API documentation
- **Security Testing**: OWASP ZAP integration for security scanning
- **Performance Testing**: Load testing with configurable thresholds
- **Container Support**: Docker-based deployment pipeline

## Usage

```yaml
include:
  - component: $CI_SERVER_FQDN/$CI_PROJECT_PATH/api/api-service@main
    inputs:
      service_name: "my-api"
      api_version: "v1"
      openapi_spec: "openapi.yaml"
      port: "3000"
```

## Inputs

| Input | Description | Type | Default | Required |
|-------|-------------|------|---------|----------|
| `service_name` | Name of the API service | string | - |  |
| `api_version` | API version for documentation | string | `v1` | ❌ |
| `openapi_spec` | Path to OpenAPI specification | string | `openapi.yaml` | ❌ |
| `port` | Service port for health checks | string | `3000` | ❌ |
| `enable_security_scan` | Enable OWASP ZAP security testing | boolean | `true` | ❌ |
| `enable_performance_test` | Enable load testing | boolean | `false` | ❌ |

## Pipeline Stages

1. **Validate**: OpenAPI spec validation, linting
2. **Build**: Application build and containerization  
3. **Test**: Unit tests, integration tests, API contract testing
4. **Security**: OWASP ZAP security scanning
5. **Performance**: Load testing (if enabled)
6. **Deploy**: Deployment to target environment

## Artifacts

- Built application artifacts
- Test reports and coverage
- Security scan results
- Performance test results
- Generated API documentation

## Requirements

- OpenAPI 3.0+ specification file
- Valid `package.json` or equivalent dependency file
- Health check endpoint at `/health`

## License

MIT License - see LICENSE.md for details