# llmcli Automation Component

This component provides intelligent automation services for llmcli to optimize CI/CD workflows.

## Usage

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/llmcli/automation@main
    inputs:
      project_type: nodejs
      environment: production
      ai_provider: openai
```

## Features

This component provides:

- AI-powered test generation and analysis
- Dynamic component adaptation for different project types
- Performance optimization and resource allocation
- Multi-environment deployment orchestration
- Caching strategy optimization

## Services

The component includes these services:

- `llmcliAutomationService.js`: Core service for automation features

## Scripts

This component provides the following CI/CD jobs:

- `llmcli-automation-setup`: Sets up the automation environment
- `llmcli-test-analysis`: Analyzes test strategy for the project
- `llmcli-component-adaptation`: Adapts component configuration for the project type
- `llmcli-resource-optimization`: Calculates optimal resource allocation
- `llmcli-deployment-orchestration`: Orchestrates multi-environment deployment

## Inputs

| Input | Description | Type | Default | Required |
|-------|-------------|------|---------|----------|
| `project_type` | Type of project | string | `auto` | ❌ |
| `environment` | Target environment | string | `development` | ❌ |
| `ai_provider` | AI provider for test generation | string | `openai` | ❌ |
| `enable_test_generation` | Enable AI-powered test generation | boolean | `true` | ❌ |
| `enable_performance_optimization` | Enable performance optimization | boolean | `true` | ❌ |
| `cache_ttl` | Cache TTL in seconds | number | `3600` | ❌ |

## Examples

### Basic Usage

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/llmcli/automation@main
    inputs:
      project_type: nodejs
```

### Production Environment with Custom Settings

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/llmcli/automation@main
    inputs:
      project_type: drupal
      environment: production
      ai_provider: anthropic
      cache_ttl: 7200
```

### Development Mode with Minimal Features

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/llmcli/automation@main
    inputs:
      project_type: microservice
      environment: development
      enable_test_generation: false
      enable_performance_optimization: false
```

## License

MIT License - see LICENSE.md for details