# llmcli Project Templates Component

This component provides standardized project templates for llmcli project setup commands. These templates make it easy to set up CI/CD pipelines for different project types using golden components.

## Usage

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/llmcli/project-templates@main
    inputs:
      project_type: drupal_module
      output_path: ./ci-templates
```

## Features

This component provides:

- Ready-to-use GitLab CI/CD templates for different project types
- Templates that use the golden components for complete CI/CD pipelines
- Consistent structure and conventions across all project types
- Comprehensive documentation and examples in the templates

## Templates

The component includes these template files:

- `drupal-golden-module-template.gitlab-ci.yml`: Template for Drupal modules
- `drupal-golden-recipe-template.gitlab-ci.yml`: Template for Drupal recipes
- `drupal-golden-site-template.gitlab-ci.yml`: Template for Drupal sites
- `nodejs-golden-package-template.gitlab-ci.yml`: Template for Node.js packages

## Scripts

This component provides the following CI/CD jobs:

- `llmcli-project-template-setup`: Sets up the project template for the specified project type

## Inputs

| Input | Description | Type | Default | Required |
|-------|-------------|------|---------|----------|
| `project_type` | Type of project to generate template for | string | `nodejs_package` | ❌ |
| `output_path` | Directory to output the templates | string | `./ci-templates` | ❌ |

## Examples

### Generate Drupal Module Template

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/llmcli/project-templates@main
    inputs:
      project_type: drupal_module
```

### Generate Node.js Package Template

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/llmcli/project-templates@main
    inputs:
      project_type: nodejs_package
      output_path: ./templates
```

## Integration with llmcli

These templates are designed to be used with the llmcli project setup commands, which can automatically generate and configure GitLab CI/CD pipelines for new projects. When using llmcli to initialize a new project, the appropriate template will be selected based on the project type and customized with the provided inputs.

## Template Customization

Each template includes detailed comments explaining all available options and customization points. The templates are designed to be self-documenting, with clear instructions for users on how to adapt them to their specific project requirements.

## License

MIT License - see LICENSE.md for details