# ESLint Config Component

ESLint configuration utilities to ensure consistent code quality across all projects.

## Usage

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/ci/eslint-config@main
    inputs:
      config_format: "flat" # or "legacy"
      typescript: true
      react: true
      jest: true
```

## Features

This component provides:

- Ready-to-use ESLint configurations for different project types
- Support for both flat (new) and legacy ESLint config formats
- TypeScript, React, and Jest integration
- Standardized rule sets aligned with Bluefly best practices
- Automatic validation in CI/CD pipelines

## Scripts

This component provides the following CI/CD scripts:

- `eslint-setup-job`: Sets up the appropriate ESLint configuration based on inputs
- `eslint-validate-job`: Runs ESLint validation on the codebase

## Inputs

| Input | Description | Type | Default | Required |
|-------|-------------|------|---------|----------|
| `project_type` | Type of project | string | `auto` | ❌ |
| `environment` | Target environment | string | `development` | ❌ |
| `config_format` | ESLint configuration format (flat or legacy) | string | `flat` | ❌ |
| `typescript` | Include TypeScript support | boolean | `true` | ❌ |
| `react` | Include React support | boolean | `false` | ❌ |
| `jest` | Include Jest support | boolean | `true` | ❌ |

## Configuration Files

The component includes these configuration files:

- `config/eslint.config.ts`: Modern flat configuration format
- `config/eslintrc.js`: Legacy configuration format (auto-created from flat config)

## Examples

### Basic Usage (TypeScript Project)

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/ci/eslint-config@main
    inputs:
      config_format: "flat"
      typescript: true
      jest: true
```

### React Project

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/ci/eslint-config@main
    inputs:
      config_format: "flat"
      typescript: true
      react: true
      jest: true
```

## License

MIT License - see LICENSE.md for details