# ESLint Configuration Component

## Overview

The ESLint Configuration Component provides a standardized, shareable ESLint configuration for TypeScript projects across the bluefly.io ecosystem. It ensures consistent code quality, style, and best practices across all projects.

## Features

- Standardized ESLint configuration for TypeScript projects
- Supports custom rule overrides
- Validates ESLint configurations
- Generates and saves ESLint configuration files
- Integrates with TypeScript, Jest, and import plugins

## Installation

```bash
npm install @ac/ci-components
```

## Usage

### Generating a Standard Configuration

```typescript
import [eslintConfigManager] from '@ac/ci-components';

// Generate a standard ESLint configuration
const standardConfig = eslintConfigManager.generateConfig();

// Generate a configuration with custom rules
const customConfig = eslintConfigManager.generateConfig({
  rules: {
    'max-len': ['error', { code: 100 }]
  }
});
```

### Saving Configuration to a File

```typescript
// Save the configuration to eslint.config.js
await eslintConfigManager.saveConfig(standardConfig);

// Save to a custom file path
await eslintConfigManager.saveConfig(customConfig, 'custom-eslint.config.js');
```

### Validating Configuration

```typescript
// Validate an ESLint configuration
const validationResult = eslintConfigManager.validateConfig(customConfig);

if (validationResult.valid) {
  console.log('Configuration is valid');
} else {
  console.error('Configuration is invalid', validationResult.errors);
}
```

## Configuration Options

The `generateConfig()` method accepts an optional configuration object with the following schema:

- `extends`: Array of extended configurations
- `rules`: Custom ESLint rules
- `overrides`: File-specific rule overrides

## Default Configuration

The default configuration includes:

- Recommended ESLint and TypeScript ESLint rules
- Import order enforcement
- Unused variable handling
- Node.js and Jest global variables
- TypeScript parser configuration

## Best Practices

1. Use the generated configuration as a base for your project
2. Customize rules sparingly
3. Maintain consistency across projects
4. Regularly update the ESLint configuration component

## Troubleshooting

- Ensure all required peer dependencies are installed
- Check that your project uses a compatible TypeScript version
- Verify that the `tsconfig.json` path is correct

## Contributing

Contributions are welcome! Please submit a merge request with your proposed changes.

## License

MIT License - See LICENSE.md for details 