# Claude Autotest - AI-Powered Test Generation

**Automated, self-healing TDD coverage for Node.js, Drupal, and more.**

[![GitLab CI](https://img.shields.io/badge/GitLab%20CE-Compatible-blue)](https://gitlab.bluefly..io)
[![Claude API](https://img.shields.io/badge/Claude%20API-Integrated-green)](https://anthropic.com)
[![Coverage](https://img.shields.io/badge/Coverage-100%25-brightgreen)](https://github.com/llm-platform/claude-autotest)
[![Self-Healing](https://img.shields.io/badge/Self--Healing-Enabled-orange)](https://github.com/llm-platform/claude-autotest)

## Key Features

- **AI-Powered Test Generation**: Generates unit, integration, and E2E tests for supported languages and frameworks.
- **Self-Healing**: Automatically updates tests when code changes.
- **TDD Workflow**: Enforces red-green-refactor cycles and test-first development.
- **Multi-Language Support**: Node.js (Jest), PHP (PHPUnit), Python (pytest), Drupal, and more.
- **OpenAPI Integration**: Generates and validates API tests from OpenAPI specs.
- **CI/CD Integration**: Designed for GitLab pipelines and BFCIComponents.

## Quick Start

### 1. Installation

Add to your `.gitlab-ci.yml`:

```yaml
include:
  - component: gitlab.bluefly..io/llmcli/bfcicomponents/claude-autotest@main
    inputs:
      claude_mode: "tdd-workflow"
      project_type: "drupal"  # or "nodejs", "php", etc.
      autotest_level: "comprehensive"
      enable_tdd_enforcement: true
      coverage_threshold: 95
```

### 2. Environment Setup

```bash
export ANTHROPIC_API_KEY="your-claude-api-key"
```

### 3. Project Configuration

Create `claude-autotest.config.json` as needed for custom settings.

## Best Practices: Drupal Integration

- **Custom Modules**: Place all custom code in `web/modules/custom/`. Ensure every new service, plugin, or class has a corresponding test in `tests/src/`.
- **TDD Enforcement**: Use the TDD workflow to require tests before code merges. Fail the pipeline if coverage drops or tests are missing.
- **OpenAPI-Driven Testing**: Store OpenAPI specs in `web/modules/custom/*/openapi/` and enable API contract testing jobs.
- **Recipe Validation**: Validate install profiles and recipes for config schema coverage and test install/uninstall hooks.
- **Security**: Integrate security review jobs for permissions, access checks, and privacy compliance.

## Best Practices: Node.js Integration

- **Test Coverage**: Maintain high coverage for all business logic and API endpoints.
- **Self-Healing**: Enable self-healing to keep tests up-to-date with code changes.
- **OpenAPI**: Use OpenAPI specs for contract and security testing of REST APIs.

## CI/CD Integration

- Use BFCIComponents for standardized pipeline stages.
- Add jobs for linting, security, and documentation validation.
- Publish coverage and test reports as pipeline artifacts and GitLab Pages.

## Contributing

- All new features must include tests and documentation.
- Follow TDD and code review best practices.
- See `CONTRIBUTING.md` for details.

---

*Built for developers. Focused on reliability, maintainability, and automation.*