# Dependency Update Component

This component automates the process of keeping your project dependencies up-to-date and secure. It supports multiple package managers and provides flexible update strategies.

## Features

- Support for npm, yarn, and pip package managers
- Configurable update types (patch, minor, major)
- Security vulnerability scanning
- Automatic merge request creation
- Package exclusion capabilities
- Scheduled updates
- Detailed audit reports

## Usage

### Basic Usage

```yaml
include:
  - component: gitlab.bluefly.io/blueflyio/internal-projects/llm/bfllm-components/dependency-update@1.0.0
    inputs:
      package_manager: 'npm'
      update_type: 'patch'
      auto_merge: true
```

### Security-Focused Updates

```yaml
include:
  - component: gitlab.bluefly.io/blueflyio/internal-projects/llm/bfllm-components/dependency-update@1.0.0
    inputs:
      package_manager: 'npm'
      security_only: true
      auto_merge: true
```

### Advanced Configuration

```yaml
include:
  - component: gitlab.bluefly.io/blueflyio/internal-projects/llm/bfllm-components/dependency-update@1.0.0
    inputs:
      package_manager: 'npm'
      update_type: 'minor'
      auto_merge: true
      exclude_packages: 'typescript,react'
      schedule: '0 0 * * 0' # Run weekly
```

## Input Parameters

| Parameter        | Type    | Default       | Description                                                   |
| ---------------- | ------- | ------------- | ------------------------------------------------------------- |
| package_manager  | string  | "npm"         | Package manager to use (npm, yarn, pip)                       |
| update_type      | string  | "patch"       | Type of updates to apply (patch, minor, major)                |
| auto_merge       | boolean | false         | Whether to automatically create merge requests                |
| security_only    | boolean | false         | Whether to only update packages with security vulnerabilities |
| exclude_packages | string  | ""            | Comma-separated list of packages to exclude                   |
| schedule         | string  | "0 0 \* \* 0" | Cron schedule for running updates                             |

## Reports

The component generates the following reports:

1. `audit-report.json`: Security audit results for the current dependencies


These reports are available as artifacts and can be viewed in the GitLab UI.

## Best Practices

1. **Regular Updates**: Schedule weekly dependency updates
2. **Security First**: Enable security_only for critical projects
3. **Gradual Updates**: Start with patch updates and gradually move to minor/major
4. **Exclusions**: Use exclude_packages for packages that need manual updates
5. **Auto Merge**: Enable auto_merge for less critical projects


## Troubleshooting

### Common Issues

1. **Update Failures**: Check for incompatible package versions
2. **Build Failures**: Test updates in a separate branch before merging
3. **Security Alerts**: Review security reports regularly


### Getting Help

For issues with the dependency update component, please:

1. Check the GitLab pipeline logs
2. Review the audit reports
3. Contact the BFCIComponents maintainers


## Security Considerations

- Regular dependency updates help prevent security vulnerabilities
- Security reports are generated for each update
- Sensitive package information is handled securely
