# Drupal Build Component

GitLab CI/CD component for building Drupal applications with optimized asset compilation.

## Features

- Composer dependency management with optimization
- Frontend asset compilation (CSS, JS, images)
- Multiple build environments (dev, staging, production)
- Asset optimization and minification
- Cache warming and optimization
- Build artifact generation and validation

## Usage

```yaml
include:
  - component: gitlab.bluefly..io/bluefly/bfcicomponents/drupal-build@main

build_production:
  extends: .drupal_build
  variables:
    php_version: "8.3"
    environment: "production"
    optimize_assets: "true"
```

## Inputs

| Input | Type | Default | Description |
|-------|------|---------|-------------|
| `php_version` | string | "8.3" | PHP version to use (8.1, 8.2, 8.3, 8.4) |
| `environment` | string | "production" | Build environment (dev, staging, production) |
| `optimize_assets` | string | "true" | Enable asset optimization |
| `install_dev_deps` | string | "false" | Install development dependencies |
| `run_composer_audit` | string | "true" | Run security audit on dependencies |
| `warm_cache` | string | "true" | Warm Drupal cache after build |
| `validate_build` | string | "true" | Validate build integrity |

## Output Artifacts

- Built application code
- Compiled assets (CSS, JS, images)
- Composer lock file
- Build reports and metrics
- Security audit reports

## Requirements

- Drupal 9.5+ or Drupal 10+
- Composer 2.0+
- Node.js (if frontend build required)
- Build tools configured in project