# Drupal Cron Component

GitLab CI/CD component for scheduled Drupal cron jobs and maintenance tasks.

## Features

- Scheduled cron execution with flexible timing
- Database maintenance and cleanup tasks
- Cache warming and optimization
- Backup automation
- Log rotation and cleanup
- Performance monitoring and alerts

## Usage

```yaml
include:
  - component: gitlab.bluefly..io/bluefly/bfcicomponents/drupal-cron@main

nightly_maintenance:
  extends: .drupal_cron
  variables:
    schedule: "0 2 * * *"
    tasks: "cron,cache-warm,cleanup"
  rules:
    - if: $CI_PIPELINE_SOURCE == "schedule"
```

## Inputs

| Input | Type | Default | Description |
|-------|------|---------|-------------|
| `schedule` | string | "0 * * * *" | Cron schedule expression |
| `tasks` | string | "cron" | Comma-separated tasks to run |
| `environment` | string | "production" | Target environment |
| `timeout` | string | "3600" | Task timeout in seconds |
| `enable_monitoring` | string | "true" | Enable monitoring and alerts |
| `cleanup_days` | string | "30" | Days to retain logs and backups |

## Available Tasks

- `cron` - Run Drupal cron
- `cache-warm` - Warm site caches
- `cleanup` - Clean temporary files and logs
- `backup` - Create database backup
- `security-update` - Check for security updates
- `performance-check` - Run performance analysis

## Requirements

- Drupal site with cron configured
- Database access for maintenance tasks
- Storage for backups and logs
- Monitoring endpoints configured