# Drupal Deployment Component

GitLab CI/CD component for deploying Drupal applications with zero-downtime strategies.

## Features

- Multiple deployment strategies (rolling, blue-green, canary)
- Database migration and configuration management
- Backup and rollback capabilities
- Health checks and smoke tests
- Multi-environment support
- Kubernetes and traditional server deployment

## Usage

```yaml
include:
  - component: gitlab.bluefly..io/bluefly/bfcicomponents/drupal-deploy@main

deploy_production:
  extends: .drupal_deploy
  variables:
    environment: "production"
    deployment_strategy: "rolling"
    run_migrations: "true"
```

## Inputs

| Input | Type | Default | Description |
|-------|------|---------|-------------|
| `environment` | string | "staging" | Deployment environment |
| `deployment_strategy` | string | "rolling" | Deployment strategy (rolling, blue-green, canary) |
| `run_migrations` | string | "true" | Run database migrations |
| `backup_database` | string | "true" | Backup database before deployment |
| `run_smoke_tests` | string | "true" | Run smoke tests after deployment |
| `enable_maintenance` | string | "false" | Enable maintenance mode during deployment |
| `rollback_on_failure` | string | "true" | Automatic rollback on deployment failure |
| `health_check_timeout` | string | "300" | Health check timeout in seconds |

## Output Artifacts

- Deployment logs and reports
- Database backup files
- Health check results
- Rollback scripts
- Performance metrics

## Requirements

- Deployment target configured
- Database access for migrations
- Health check endpoints configured
- Backup storage available