# Drupal Prepare Component

This component prepares the environment for Drupal projects by setting up PHP, Composer, Node.js (if needed), and database services.

## Features

-  **Multi-PHP Support**: PHP 8.1, 8.2, 8.3, 8.4
-  **Multi-Database Support**: MySQL, MariaDB, PostgreSQL
-  **Composer Optimization**: Caching and optimization
-  **Node.js Integration**: Automatic detection and setup
-  **Drupal Installation**: Fresh Drupal site for testing
-  **Development Tools**: Optional Xdebug support
-  **Configurable Resources**: Memory limits, upload sizes

## Usage

### Basic Usage
```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/drupal-prepare@main
```

### Advanced Configuration
```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/drupal-prepare@main
    inputs:
      php_version: "8.3"
      drupal_version: "11.x"
      database: "postgres:14"
      memory_limit: "1G"
      enable_xdebug: true
      install_dev_dependencies: true
```

## Inputs

| Input | Default | Description | Options |
|-------|---------|-------------|----------|
| `php_version` | `8.3` | PHP version to use | `8.1`, `8.2`, `8.3`, `8.4` |
| `drupal_version` | `11.x` | Drupal version | `10.x`, `11.x`, `latest` |
| `database` | `mysql:8.0` | Database service | `mysql:5.7`, `mysql:8.0`, `mariadb:10.6`, `postgres:14` |
| `cache_strategy` | `composer` | Caching strategy | `composer`, `npm`, `vendor`, `all` |
| `install_dev_dependencies` | `true` | Install dev dependencies | `true`, `false` |
| `memory_limit` | `512M` | PHP memory limit | Any valid PHP memory value |
| `upload_max_filesize` | `64M` | Max upload size | Any valid PHP size value |
| `enable_xdebug` | `false` | Enable Xdebug | `true`, `false` |

## Outputs

This component creates the following artifacts:

- `vendor/` - Composer dependencies
- `web/` - Drupal installation
- `node_modules/` - Node.js dependencies (if applicable)
- `prepare.env` - Environment variables for subsequent jobs

## Environment Variables

The component sets these environment variables for subsequent jobs:

- `DRUPAL_PREPARED=true`
- `PHP_VERSION` - The PHP version used
- `DRUPAL_VERSION` - The Drupal version used
- `DATABASE_SERVICE` - The database service used

## Integration with Other Components

This component is designed to work with other Drupal components:

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/drupal-prepare@main
  - component: gitlab.bluefly.io/llm/bfcicomponents/drupal-lint@main
  - component: gitlab.bluefly.io/llm/bfcicomponents/drupal-test-unit@main
```

## Caching Strategy

The component uses intelligent caching:

- **Composer cache**: `$CI_PROJECT_DIR/.composer-cache`
- **Vendor directory**: `vendor/`
- **Node modules**: `node_modules/` (if applicable)
- **Cache key**: Based on PHP and Drupal versions for optimal cache hits

## Database Configuration

The component automatically configures the database service:

### MySQL/MariaDB
- Database: `drupal`
- User: `drupal`
- Password: `drupal`
- Root password: `drupal`

### PostgreSQL
- Database: `drupal`
- User: `drupal`
- Password: `drupal`

## Troubleshooting

### Common Issues

1. **Memory limit errors**: Increase `memory_limit` input
2. **Database connection timeout**: Check database service configuration
3. **Composer install fails**: Check `composer.json` dependencies
4. **Node.js issues**: Ensure `package.json` is valid

### Debug Mode

Enable Xdebug for debugging:

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/drupal-prepare@main
    inputs:
      enable_xdebug: true
      memory_limit: "1G"
```
