# Drupal Functional Testing Component

GitLab CI/CD component for running Drupal functional tests with browser automation.

## Features

- Full Drupal functional testing with browser simulation
- Headless Chrome/Firefox support via Selenium
- Screenshot capture on test failures
- Performance testing with real user interactions
- Multi-browser testing capabilities
- Accessibility testing integration
- Visual regression testing support

## Usage

```yaml
include:
  - component: gitlab.bluefly..io/bluefly/bfcicomponents/drupal-test-functional@main

functional_tests:
  extends: .drupal_functional_tests
  variables:
    php_version: "8.3"
    browser: "chrome"
    capture_screenshots: "true"
```

## Inputs

| Input | Type | Default | Description |
|-------|------|---------|-------------|
| `php_version` | string | "8.3" | PHP version to use (8.1, 8.2, 8.3, 8.4) |
| `browser` | string | "chrome" | Browser for testing (chrome, firefox) |
| `headless` | string | "true" | Run browser in headless mode |
| `capture_screenshots` | string | "true" | Capture screenshots on failures |
| `test_suite` | string | "functional" | PHPUnit test suite to run |
| `accessibility_tests` | string | "false" | Enable accessibility testing |
| `performance_budget` | string | "3000" | Performance budget in milliseconds |
| `parallel_jobs` | string | "2" | Number of parallel browser instances |

## Output Artifacts

- Functional test results (JUnit XML)
- Screenshots and videos of test runs
- Performance metrics and timing reports
- Accessibility audit reports
- Browser console logs

## Requirements

- Drupal 9.5+ or Drupal 10+
- Selenium WebDriver or ChromeDriver
- Functional test base classes configured
- Web server running during tests