# Drupal Unit Testing Component

GitLab CI/CD component for running Drupal unit tests with comprehensive configuration options.

## Features

- PHPUnit unit testing with Drupal-specific configuration
- Multi-PHP version support (8.1-8.4)
- Configurable test coverage reporting
- JUnit XML output for GitLab integration
- Artifact collection and caching
- Error handling and retry logic
- Memory management for large test suites

## Usage

```yaml
include:
  - component: gitlab.bluefly..io/bluefly/bfcicomponents/drupal-test-unit@main

unit_tests:
  extends: .drupal_unit_tests
  variables:
    php_version: "8.3"
    coverage_enabled: "true"
    memory_limit: "512M"
```

## Inputs

| Input | Type | Default | Description |
|-------|------|---------|-------------|
| `php_version` | string | "8.3" | PHP version to use (8.1, 8.2, 8.3, 8.4) |
| `coverage_enabled` | string | "false" | Enable code coverage reporting |
| `coverage_format` | string | "html" | Coverage format (html, clover, text) |
| `test_suite` | string | "unit" | PHPUnit test suite to run |
| `memory_limit` | string | "256M" | PHP memory limit for tests |
| `parallel_jobs` | string | "1" | Number of parallel test processes |
| `retry_count` | string | "2" | Number of retries on failure |

## Output Artifacts

- Test results (JUnit XML)
- Coverage reports (HTML/Clover)
- Test logs and screenshots
- Performance metrics

## Requirements

- Drupal 9.5+ or Drupal 10+
- PHPUnit 9.5+ configured
- Composer dependencies installed