# Drupal Golden CI Recipe Component

This component provides a comprehensive CI/CD pipeline for Drupal projects by combining various specialized Drupal components. It aims to offer a "golden path" for Drupal development, incorporating best practices for testing, building, deployment, security, and performance.

## Usage

```yaml
include:
  - component: $CI_SERVER_FQDN/$CI_PROJECT_PATH/drupal_golden_ci_recipe@main # Or specific version
    inputs:
      # Configure inputs for the golden recipe and underlying components as needed
      php_version: "8.3"
      drupal_version: "11.x"
      environment: "staging"
      # Add other relevant inputs that might be shared or specific
```

## Included Components

This golden recipe component integrates the functionality of the following individual components:

-   `ai-platform`: For AI platform deployment and multi-tenant AI platform setup.
-   `llmcli-drupal-platform`: For llmcli Drupal platform integration.
-   `drupal-ai-site-testing`: For AI-powered Drupal site testing and analysis.
-   `drupal-build`: For building Drupal applications with optimized asset compilation.
-   `drupal-cron`: For scheduled Drupal cron jobs and maintenance tasks.
-   `drupal-deploy`: For deploying Drupal applications with zero-downtime strategies.
-   `drupal-e2e-testing`: For comprehensive E2E testing integration.
-   `drupal-lint`: For code quality and standards checking.
-   `drupal-modules`: For Drupal module package management.
-   `drupal-packagist`: For enterprise Drupal module publishing to Packagist.
-   `drupal-performance`: For performance testing, benchmarking, and optimization.
-   `drupal-prepare`: For preparing the environment for Drupal projects.
-   `drupal-scheduled-tests`: For running scheduled tests and health monitoring.
-   `drupal-security`: For comprehensive Drupal security scanning and hardening.
-   `drupal-self-healing`: For automated Drupal site monitoring and recovery.
-   `drupal-tdd`: For Test-Driven Development setup and execution.
-   `drupal-tdd-enforcer`: For enforcing TDD practices.
-   `drupal-tdd-enhanced`: For enhanced TDD capabilities.
-   `drupal-tdd-legacy`: For TDD with legacy Drupal versions.
-   `drupal-tdd-mutation`: For mutation testing in a TDD workflow.
-   `drupal-test-functional`: For Drupal functional testing.
-   `drupal-test-kernel`: For Drupal kernel testing.
-   `drupal-test-unit`: For Drupal unit testing.
-   `drupal-ui-ux-testing`: For UI/UX testing of Drupal sites.

## Inputs

This component will expose a set of inputs that configure its behavior and the behavior of the included components. Refer to the individual component `README.md` files for details on their specific inputs. Commonly overridden inputs might include:

| Input             | Description                                     | Type   | Default    |
| ----------------- | ----------------------------------------------- | ------ | ---------- |
| `php_version`     | PHP version to use across various stages        | string | `"8.3"`    |
| `drupal_version`  | Target Drupal version for tests and builds      | string | `"11.x"`   |
| `environment`     | Target environment (e.g., dev, staging, prod)   | string | `staging`  |
| `base_url`        | Base URL for the Drupal site being tested/deployed | string | `http://localhost` |
| `deploy_target`   | Specifies the deployment target or strategy     | string | `kubernetes` |
| `run_all_tests`   | Flag to run all available test suites           | bool   | `true`     |
| `enable_security_scans` | Enable comprehensive security scanning    | bool   | `true`     |
| `enable_performance_tests` | Enable performance and load testing  | bool   | `true`     |
| `packagist_token` | Token for publishing to Packagist (if applicable) | string | `""`       |

*(This is a representative list; actual inputs will be defined in `template.yml`)*

## Features

-   **Comprehensive Pipeline**: Covers all aspects of the Drupal development lifecycle.
-   **Best Practices**: Incorporates established best practices for Drupal CI/CD.
-   **Modularity**: Leverages individual, focused components for maintainability.
-   **Configurability**: Allows fine-tuning through inputs passed to the underlying components.
-   **Extensibility**: Designed to be a starting point that can be further customized.

## Requirements

-   GitLab 17.0+ for component support.
-   Project structure compatible with the included Drupal components.
-   Relevant CI/CD variables (e.g., API keys, registry credentials) configured at the project or group level.

## License

MIT License - see `LICENSE.md` for details. 