# Drupal Golden CI Site Component

This component provides a comprehensive, all-encompassing CI/CD pipeline for complete Drupal projects/sites. It orchestrates a full suite of development, testing, deployment, and maintenance operations, leveraging best practices from various specialized Drupal CI components.

## Usage

```yaml
include:
  - component: $CI_SERVER_FQDN/$CI_PROJECT_PATH/drupal_golden_ci_site@main # Or specific version
    inputs:
      php_version: "8.3"
      drupal_version: "11.x"
      environment: "staging" # e.g., development, staging, production
      base_url: "https://staging.example.com"
      # Add other relevant inputs as needed
```

## Purpose

This component is designed to be the primary CI/CD configuration for a full Drupal website. It integrates workflows for:

-   **Environment Preparation**: Setting up PHP, database, and Drupal.
-   **Code Quality**: Linting PHP, JS, CSS; static analysis.
-   **Comprehensive Testing**: Unit, Kernel, Functional, E2E, AI-powered site testing, UI/UX testing, performance, and security testing.
-   **Build & Asset Management**: Compiling frontend assets, optimizing images.
-   **Deployment**: Strategies for deploying to various environments (e.g., staging, production).
-   **Post-Deployment**: Cache clearing, database updates, cron runs.
-   **Scheduled Tasks**: Automated cron, backups, health checks, and scheduled tests.
-   **Security Hardening**: Applying security best practices and scanning.
-   **Performance Optimization**: Tools and checks for site performance.
-   **Self-Healing**: Basic mechanisms for site monitoring and recovery (if applicable component is used).
-   **TDD Enforcement**: Optional TDD practice enforcement.

## Leveraged Components (Conceptual)

This site-level golden recipe builds upon the capabilities of numerous fine-grained components, including but not limited to:

-   `drupal-prepare`
-   `drupal-lint`
-   `drupal-security`
-   `drupal-build`
-   `drupal-tdd`, `drupal-test-unit`, `drupal-test-kernel`, `drupal-test-functional`, `drupal-e2e-testing`
-   `drupal-ai-site-testing`, `drupal-ui-ux-testing`
-   `drupal-performance`
-   `drupal-deploy`
-   `drupal-cron`, `drupal-scheduled-tests`
-   `drupal-self-healing` (if integrated)
-   `ai-platform`, `llmcli-drupal-platform` (if Bluefly.io specific integrations are needed)

## Inputs

Key inputs for this comprehensive site component would include:

| Input                         | Description                                                                 | Type    | Default            |
| ----------------------------- | --------------------------------------------------------------------------- | ------- | ------------------ |
| `php_version`                 | PHP version for the entire pipeline.                                        | string  | `"8.3"`            |
| `drupal_version`              | Drupal core version for the site.                                           | string  | `"11.x"`           |
| `environment`                 | Target environment (e.g., `development`, `staging`, `production`).          | string  | `staging`          |
| `base_url`                    | Base URL of the Drupal site for testing and deployment.                     | string  | `http://localhost` |
| `deployment_strategy`         | Deployment strategy (e.g., `rolling`, `blue-green`).                      | string  | `rolling`          |
| `enable_all_tests`            | Master flag to enable/disable all major test categories.                  | boolean | `true`             |
| `enable_ai_site_testing`      | Enable AI-powered site analysis.                                            | boolean | `true`             |
| `enable_performance_testing`  | Enable comprehensive performance and load testing.                          | boolean | `true`             |
| `enable_security_scanning`    | Enable in-depth security scanning.                                          | boolean | `true`             |
| `cron_schedule`               | Cron schedule for maintenance tasks (e.g., `"0 2 * * *"`).                 | string  | `"0 2 * * *"`      |
| `scheduled_tests_schedule`    | Cron schedule for running extensive scheduled tests.                        | string  | `"0 3 * * *"`      |
| `packagist_token`             | Packagist token (if project includes custom modules to be published).       | string  | `""`               |

*(This is a high-level list. The `template.yml` will detail more specific inputs passed to underlying components.)*

## Features

-   **End-to-End Automation**: From commit to deployment and ongoing maintenance.
-   **Holistic Quality Assurance**: Integrates all forms of testing and validation.
-   **Environment-Aware**: Configurable behavior for different deployment environments.
-   **Best-Practice Driven**: Built upon a suite of specialized, best-practice components.

## Requirements

-   GitLab 17.0+ for component support.
-   A standard Drupal project structure.
-   All necessary CI/CD variables (database credentials, API keys, deployment targets) configured in GitLab.

## License

MIT License - see `LICENSE.md` for details. 