# LangChain Drupal Module Component

Enhanced LangChain integration for Drupal with advanced AI capabilities, RAG implementation, and workflow orchestration.

## Usage

```yaml
include:
  - component: $CI_SERVER_FQDN/$CI_PROJECT_PATH/langchain@main
    inputs:
      # Component-specific inputs
      drupal_version: '11.0'
      php_version: '8.3'
      enable_ml_optimization: true
      enable_observability: true
      enable_advanced_rag: true
      test_coverage_threshold: 85
```

## Inputs

| Input | Description | Type | Default | Required |
|-------|-------------|------|---------|----------|
| `drupal_version` | Drupal version to use | string | `11.0` | ❌ |
| `php_version` | PHP version to use | string | `8.3` | ❌ |
| `enable_ml_optimization` | Enable machine learning optimizations | boolean | `true` | ❌ |
| `enable_observability` | Enable Langfuse observability integration | boolean | `true` | ❌ |
| `enable_advanced_rag` | Enable advanced RAG capabilities | boolean | `true` | ❌ |
| `enable_langgraph` | Enable LangGraph workflow orchestration | boolean | `true` | ❌ |
| `test_coverage_threshold` | Minimum test coverage percentage | number | `85` | ❌ |
| `memory_limit` | PHP memory limit for tests | string | `512M` | ❌ |
| `vector_db` | Vector database to use (pg_vector, qdrant, milvus) | string | `pg_vector` | ❌ |
| `advanced_testing` | Enable advanced testing features | boolean | `true` | ❌ |

## Features

- Complete LangChain Drupal module implementation
- LlmPlatformBridgeProvider integration with multiple LLM providers
- SelfOptimizingLangChainService with ML capabilities
- RAG implementation with vector storage
- LangGraph submodule for workflow orchestration
- Agent reasoning loop
- Enhanced controllers with RESTful API support
- Prompt template system with version control
- Comprehensive test coverage
- Observability through Langfuse integration
- ECA rule integration
- Context-aware AI responses
- Auto-optimization of prompts and chains

## Requirements

- GitLab 17.0+ for component support
- Drupal 10.0+ or 11.0+
- PHP 8.2+ (8.3+ recommended)
- LLM Platform Recipe 2.0+
- Access to vector database (PostgreSQL with pg_vector extension, Qdrant, or Milvus)

## Architecture

The LangChain Drupal module provides a robust framework for integrating language models into Drupal applications:

1. **Core Services**:
   - SelfOptimizingLangChainService for AI request optimization
   - PromptTemplateManager for handling prompt templates
   - VectorStore for embedding storage and retrieval
   - AgentReasoningLoop for advanced reasoning capabilities

2. **Provider System**:
   - LlmPlatformBridgeProvider for LLM Platform integration
   - Provider plugins for OpenAI, Anthropic, and other LLM providers
   - Enhanced provider registry for dynamic discovery

3. **RAG Implementation**:
   - Document processing pipeline
   - Embedding generation
   - Vector storage and retrieval
   - Context enhancement

4. **Workflow Orchestration**:
   - LangGraph integration
   - Workflow node system
   - Conditional routing
   - State management

5. **Observability**:
   - Langfuse integration
   - Performance tracking
   - Cost monitoring
   - Trace visualization

## License

MIT License - see LICENSE.md for details