# Logging Component

A GitLab CI/CD component for structured logging and error handling.

## Features

- Structured logging
- Error tracking
- Performance monitoring
- Log rotation
- Test automation

## Inputs

| Input         | Required | Default  | Description                         |
| ------------- | -------- | -------- | ----------------------------------- |
| log_level     | No       | "info"   | Minimum log level to record         |
| log_dir       | No       | "./logs" | Directory to store log files        |
| max_file_size | No       | 10485760 | Maximum size of log files in bytes  |
| max_files     | No       | 5        | Maximum number of log files to keep |
| log_format    | No       | "json"   | Format of log messages (json/text)  |

## Usage

```yaml
include:
  - component: gitlab.com/your-namespace/bfci-components/logging@1.0.0
    inputs:
      log_level: 'info'
      log_dir: './logs'
```

## Testing

The component includes automated tests that verify:

1. Log message formatting
2. Log level filtering
3. File rotation
4. Error handling
5. Performance impact


To run tests locally:

```bash
./test.sh
```

## Artifacts

The component generates the following artifacts:

- Test reports in JUnit format
- Coverage reports
- Log files
- Error reports
- Performance metrics

## Logging Levels

The component supports the following log levels:

- error: Critical errors that require immediate attention
- warn: Warning messages for potential issues
- info: General operational information
- debug: Detailed debugging information
- trace: Very detailed tracing information

## Contributing

1. Fork the repository
2. Create a feature branch
3. Submit a merge request


## License

MIT License - See LICENSE.md for details
