# ML Node Package CI Component

This CI component provides a complete pipeline for Node.js packages with machine learning capabilities, including:

- Multi-architecture Docker builds (AMD64, ARM64)
- ML model training, evaluation, and optimization
- Integration with MLflow for model tracking
- VLLM and Axolotl support
- Comprehensive testing and benchmarking
- Performance and memory optimization
- Security scanning and hardening

## Usage

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/nodejs/ml_node_package@main
    inputs:
      node_version: "20"
      python_version: "3.11"
      enable_mlflow: true
      enable_vllm: true
      enable_axolotl: true
      tensor_parallel_size: "2"
      mlflow_server_url: "https://mlflow.bluefly.io"
```

## Inputs

| Name | Description | Default | Required |
|------|-------------|---------|----------|
| node_version | Node.js version | "20" | No |
| python_version | Python version | "3.11" | No |
| npm_token | NPM token for publishing | | Yes |
| release_branch | Branch to release from | "main" | No |
| package_manager | Package manager (npm, yarn, pnpm) | "npm" | No |
| enable_mlflow | Enable MLflow integration | true | No |
| enable_vllm | Enable VLLM optimization | true | No |
| enable_axolotl | Enable Axolotl integration | false | No |
| tensor_parallel_size | Tensor parallel size for VLLM | "2" | No |
| ml_image_tag | ML image tag | "nvcr.io/nvidia/pytorch:23.10-py3" | No |
| mlflow_server_url | MLflow server URL | "https://mlflow.bluefly.io" | No |
| min_test_coverage | Minimum test coverage | 90 | No |
| enable_multi_arch | Enable multi-architecture builds | true | No |

## Example Configuration

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/nodejs/ml_node_package@main
    inputs:
      node_version: "20"
      python_version: "3.11"
      enable_mlflow: true
      enable_vllm: true
      enable_axolotl: true
      tensor_parallel_size: "2"
      mlflow_server_url: "https://mlflow.bluefly.io"
      min_test_coverage: 90

# Optional: Add custom jobs that extend from base jobs
my_custom_benchmark:
  extends: .benchmark_job
  script:
    - echo "Running custom benchmark"
    - npm run benchmark:custom
```