# Security Scan Component

A GitLab CI/CD component for automated security scanning and vulnerability detection.

## Features

- Multiple scan types (SAST, DAST, Dependency, Container)
- Configurable severity levels
- Custom security rules
- Path exclusions
- Custom Docker image support
- Comprehensive reporting
- Pipeline failure control

## Usage

Include this component in your `.gitlab-ci.yml`:

```yaml
include:
  - component: gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bfci-components/security-scan@1.0.0
    inputs:
      enabled: true
      scan_type: 'all'
      severity_level: 'medium'
      fail_on_findings: true
      exclude_paths:
        - 'node_modules/'
        - 'vendor/'
      custom_rules: 'security/rules.yml'
```

## Inputs

| Input             | Type    | Default                          | Description                                      |
| ----------------- | ------- | -------------------------------- | ------------------------------------------------ |
| enabled           | boolean | true                             | Enable security scanning                         |
| scan_type         | string  | "all"                            | Type of security scan to perform                 |
| severity_level    | string  | "medium"                         | Minimum severity level to report                 |
| fail_on_findings  | boolean | true                             | Fail the pipeline if vulnerabilities are found   |
| exclude_paths     | array   | []                               | Paths to exclude from scanning                   |
| custom_rules      | string  | ""                               | Path to custom security rules                    |
| use_custom_image  | boolean | true                             | Use the Bluefly custom Docker image              |
| custom_image_path | string  | "registry.gitlab.bluefly.io/..." | Path to the custom Docker image                  |
| additional_args   | string  | ""                               | Additional arguments for security scanning tools |

## Requirements

- GitLab CI/CD
- Docker runtime
- Required scanning tools (based on scan type)
- Access to security scanning services
- Proper permissions for scanning tools

## Security Considerations

1. Never commit sensitive credentials to version control
2. Use GitLab CI/CD variables for sensitive values
3. Implement proper access controls for scanning tools
4. Review scan results before deployment
5. Keep scanning tools up to date


## Examples

Check the `examples/` directory for sample configurations:

- SAST scanning for Node.js applications
- DAST scanning for web applications
- Dependency scanning for Python projects
- Container scanning for Docker images

## License

This component is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details.
