# Semantic Release CI Component

This component provides automated semantic versioning and release management for GitLab CI pipelines using semantic-release.

## Features

- Automated version determination
- Conventional Commits support
- Changelog generation
- Git tagging
- NPM package publishing
- GitHub/GitLab release creation
- Multiple plugin support

## Usage

Include this component in your GitLab CI configuration:

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/semantic-release@main
    inputs:
      release_branches: "main"
      commit_analyzer_preset: "angular"
```

## Configuration

### Basic Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `release_branches` | Branches on which releases should be triggered | "main" |
| `node_version` | Node.js version to use | "20" |
| `dryrun` | Run in dry-run mode (no actual releases) | false |
| `debug` | Enable debug output | false |

### Commit Analysis

| Parameter | Description | Default |
|-----------|-------------|---------|
| `commit_analyzer_preset` | Conventional Commits preset | "angular" |
| `commit_analyzer_release_rules` | Custom release rules | "" |
| `commit_parser_preset` | Conventional Commits parser preset | "angular" |
| `commit_parser_issue_prefixes` | Issue reference prefixes | "#" |

### Release Notes

| Parameter | Description | Default |
|-----------|-------------|---------|
| `release_notes_preset` | Release notes generator preset | "angular" |
| `release_notes_template` | Custom Handlebars template file path | "" |
| `release_notes_issue_url_format` | Issue URL format | "your-repo/issues/item" |

### Publishing

| Parameter | Description | Default |
|-----------|-------------|---------|
| `npm_publish` | Enable NPM publishing | true |
| `npm_registry` | NPM registry URL | "https://registry.npmjs.org/" |
| `npm_tag` | NPM distribution tag | "latest" |
| `gitlab_release` | Create GitLab release | true |
| `github_release` | Create GitHub release | false |
| `github_token_variable` | GitHub token variable name | "GITHUB_TOKEN" |

### Advanced Options

| Parameter | Description | Default |
|-----------|-------------|---------|
| `config_file` | Custom semantic-release config file | "" |
| `extends` | Extend existing semantic-release configurations | "" |
| `plugins` | Additional semantic-release plugins | "" |
| `ci_skip_message` | Message to skip CI builds on release commits | "[skip ci]" |
| `custom_env_variables` | Additional environment variables | "" |

## Example: Minimal Configuration

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/semantic-release@main
    inputs:
      release_branches: "main,master"
      npm_publish: true
```

## Example: Full Configuration

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/semantic-release@main
    inputs:
      # Basic Configuration
      release_branches: "main,release/*"
      node_version: "20"
      dryrun: false
      debug: true
      
      # Commit Analysis
      commit_analyzer_preset: "angular"
      commit_analyzer_release_rules: |
        [
          { "type": "feature", "release": "minor" },
          { "type": "fix", "release": "patch" },
          { "type": "docs", "release": "patch" },
          { "type": "perf", "release": "patch" },
          { "type": "refactor", "scope": "core", "release": "minor" },
          { "type": "refactor", "release": "patch" },
          { "type": "style", "release": false },
          { "type": "test", "release": false }
        ]
      commit_parser_preset: "angular"
      commit_parser_issue_prefixes: "#,JIRA-"
      
      # Release Notes
      release_notes_preset: "angular"
      release_notes_template: ".releaserc/template.hbs"
      release_notes_issue_url_format: "https://jira.example.com/browse/item"
      
      # Publishing
      npm_publish: true
      npm_registry: "https://registry.npmjs.org/"
      npm_tag: "latest"
      gitlab_release: true
      github_release: true
      github_token_variable: "GH_TOKEN"
      
      # Advanced Options
      config_file: ".releaserc.json"
      extends: "@semantic-release/gitlab-config"
      plugins: |
        [
          "@semantic-release/commit-analyzer",
          "@semantic-release/release-notes-generator",
          "@semantic-release/changelog",
          "@semantic-release/npm",
          "@semantic-release/git",
          "@semantic-release/gitlab"
        ]
      ci_skip_message: "[skip ci] [release]"
      custom_env_variables: |
        NPM_CONFIG_REGISTRY=https://registry.npmjs.org/
        HUSKY_SKIP_HOOKS=1
```

## License

MIT