# ESLint Component

This component provides standardized ESLint configurations for Bluefly CI / CD pipelines to ensure consistent code quality.

## Inputs

| Name | Type | Required | Default | Description |
|------|------|----------|---------|-------------|
| stage | string | false | validate | The stage in which to run this component |
| image | string | false | node:16 | Docker image to use for linting |
| use_custom_image | boolean | false | false | Whether to use a custom image |
| custom_image_path | string | false | "" | Path to custom Docker image if use_custom_image is true |
| eslint_version | string | false | "8.2.0" | ESLint version to use |
| prettier_version | string | false | "3.2.5" | Prettier version to use |
| eslint_config | string | false | "recommended" | ESLint configuration to use |
| eslint_ignore_patterns | string | false | "node_modules, dist, coverage" | Patterns to ignore during linting |
| variables | object | false | {} | Additional variables to pass to the job |

## Usage Example

```yaml
include:
  - project: 'bluefly / internal - projects / llm / bfcicomponents'
    file: 'templates / eslint / template.yml'

lint_code:
  extends: .eslint_template
  variables:
    ESLINT_CONFIG: "airbnb"
    ESLINT_VERSION: "8.2.0"
    PRETTIER_VERSION: "3.2.5"
