# Configuration Guide

This guide explains how to configure BFCI Components for your project.

## Component Configuration

Each component can be configured through its inputs section in your `.gitlab - ci.yml`file:

```yaml
include:
  - component: registry.gitlab.bluefly.io / Blueflyio / internal - projects / llm / bfcicomponents / test@1.0.0
    inputs:
      test_command: 'npm test'
      coverage_path: 'coverage'
```text

## Global Configuration
You can set global configuration options that apply to all components:

```yaml
variables:
  COMPONENT_REGISTRY: registry.gitlab.bluefly.io / Blueflyio / internal - projects / llm / bfcicomponents
  NODE_ENV: test
```text

## Environment Variables
The following environment variables are available to all components:

- `CI_JOB_TOKEN`: Used for authentication with GitLab
- `CI_PROJECT_ID`: The current project ID
- `CI_COMMIT_REF_SLUG`: The current branch / tag name
- `CI_PIPELINE_SOURCE`: The source of the pipeline trigger

## Cache Configuration
Components use GitLab's cache feature to speed up builds:

```yaml
cache:
  key: [CI_COMMIT_REF_SLUG]
  paths:
    - node_modules/
    - vendor/
    - .npm/
    - .composer/
```text

## Advanced Configuration
For advanced configuration options, refer to each component's documentation in the [Components Section](.. / components / ).
