# Development Standards Component

This component provides a comprehensive set of development standards and tooling for BlueFly projects.

## Features

- ESLint configuration with TypeScript and React support
- Jest testing setup with coverage requirements
- Prettier code formatting
- Conventional commit message validation
- Pipeline jobs for linting, testing, and formatting

## Usage

### Pipeline Configuration

Add to your `.gitlab-ci.yml`:

```yaml
include:
  - component: $CI_SERVER_FQDN/bluefly/bfcicomponents/development-standards@1.0.0
    inputs:
      node_version: '20'
      stages:
        lint: code-quality
        test: test
        format: format
      auto_fix: false
```

### ESLint Configuration

Create `.eslintrc.js`:

```javascript
module.exports = {
  extends: '@bfci/development-standards/config/eslint/base',
};
```

### Jest Configuration

Create `jest.config.js`:

```javascript
module.exports = {
  ...require('@bfci/development-standards/config/jest/jest.config'),
};
```

### Prettier Configuration

Create `.prettierrc`:

```json
[...require('@bfci/development-standards/config/prettier/.prettierrc')]
```

### Commitlint Configuration

Create `commitlint.config.js`:

```javascript
module.exports = {
  extends: ['@bfci/development-standards/config/commitlint'],
};
```

## Component Options

### Inputs

| Name          | Type    | Default  | Description                         |
| ------------- | ------- | -------- | ----------------------------------- |
| node_version  | string  | "20"     | Node.js version to use              |
| stages.lint   | string  | "lint"   | Stage name for linting              |
| stages.test   | string  | "test"   | Stage name for testing              |
| stages.format | string  | "format" | Stage name for formatting           |
| auto_fix      | boolean | false    | Whether to automatically fix issues |

## Development

### Testing

Run the test suite:

```bash
npm test
```

### Local Development

1. Clone the repository
2. Install dependencies: `npm install`
3. Run tests: `npm test`
4. Make changes
5. Submit a merge request


## License

[License details here]
