# BFCI Monitoring Component

A comprehensive system monitoring and alerting component for the Bluefly CI/CD platform.

## Features

- Real-time system resource monitoring (CPU, memory, disk, network)
- Configurable metrics collection and thresholds
- Flexible alerting system with multiple notification channels
- Extensible monitoring architecture
- Integration with BFCI platform components

## Installation

```bash
npm install @bfci/monitoring
```

## Usage

```javascript
import [SystemMonitor] from '@bfci/monitoring';

const monitor = new SystemMonitor({
  metrics: {
    cpu: { enabled: true, threshold: 80 },
    memory: { enabled: true, threshold: 90 },
    disk: { enabled: true, threshold: 85 },
    network: { enabled: true }
  },
  alerts: {
    email: {
      enabled: true,
      recipients: ['alerts@example.com']
    },
    slack: {
      enabled: true,
      webhook: process.env.SLACK_WEBHOOK
    }
  },
  interval: 60 // seconds
});

monitor.start();

monitor.on('alert', (alert) => {
  console.log('Alert:', alert);
});

monitor.on('metrics', (metrics) => {
  console.log('Metrics:', metrics);
});
```

## Configuration

### Metrics Configuration

```javascript
{
  metrics: {
    cpu: {
      enabled: boolean,
      threshold: number, // percentage
      interval: number  // seconds
    },
    memory: {
      enabled: boolean,
      threshold: number, // percentage
      interval: number  // seconds
    },
    disk: {
      enabled: boolean,
      threshold: number, // percentage
      interval: number  // seconds
    },
    network: {
      enabled: boolean,
      interval: number  // seconds
    }
  }
}
```

### Alert Configuration

```javascript
{
  alerts: {
    email: {
      enabled: boolean,
      recipients: string[],
      from: string,
      subject: string
    },
    slack: {
      enabled: boolean,
      webhook: string,
      channel: string
    }
  }
}
```

## API Reference

### SystemMonitor

Main class for system monitoring.

#### Methods

- `start()`: Start monitoring
- `stop()`: Stop monitoring
- `checkHealth()`: Get current system health status
- `monitorService(serviceName)`: Monitor specific service
- `monitorNetwork(interface)`: Monitor network traffic

#### Events

- `metrics`: Emitted when new metrics are collected
- `alert`: Emitted when thresholds are exceeded
- `error`: Emitted on monitoring errors

### PerformanceMonitor

Class for detailed performance monitoring.

#### Methods

- `startMonitoring()`: Start performance monitoring
- `stopMonitoring()`: Stop performance monitoring
- `addThreshold(metric, value)`: Add performance threshold
- `removeThreshold(metric)`: Remove performance threshold

#### Events

- `performance`: Emitted with performance metrics
- `threshold`: Emitted when thresholds are crossed

## Contributing

1. Fork the repository
2. Create your feature branch
3. Commit your changes
4. Push to the branch
5. Create a new Pull Request


## License

MIT License - see LICENSE file for details 
