---
id: components-bfcicomponents-CONTRIBUTING
---
# Contributing to LLM Platform CI Components

This guide explains how to develop and contribute components to this repository.

## Component Structure

All components should follow this standard structure:

```yaml
---
# Component name and description
# Follow this format consistently

# Component specification that defines inputs and configuration
spec:
  inputs:
    # Input name
    input_name:
      description: 'Human-readable description of the input'
      default: 'default_value'
      options: ['option1', 'option2'] # Optional list of valid options
      type: string # Optional type (string, boolean, number, array)

    # More inputs as needed...

  # Component dependencies (optional)
  depends_on:
    - name: 'other-component'
      version: '1.0.0'

# Variables section that is exported to including pipelines
variables:
  VARIABLE_NAME: $[[ inputs.input_name ]]
  # More variables as needed...

# Reusable job templates (hidden jobs that start with a dot)
.job_template:
  script:
    - echo "This is a reusable job template"
    - echo "Using input: $[[ inputs.input_name ]]"
  # More configuration as needed...

# Actual jobs that will run (conditional based on inputs)
$[[ inputs.enable_feature ]]:
  job_name:
    extends: .job_template
    stage: test
    script:
      - echo "This job only runs if enable_feature is true"
```

## Documentation

Each component needs proper documentation in the `docs/` directory:

- File name should match component name (e.g., `nodejs-build.md` for `nodejs-build.yml`)
- Include purpose, inputs, usage examples, and troubleshooting tips
- Follow the standard format shown in existing documentation

## Examples

Provide examples showing how to use your component in practical scenarios:

- Create examples in the `examples/` directory
- Examples should be complete, working `.gitlab-ci.yml` files
- Include comments explaining key configuration options

## Testing

Test your components thoroughly before contributing:

1. Create a test project with a `.gitlab-ci.yml` that uses your component
2. Run the pipeline to verify it works as expected
3. Test edge cases and different input configurations
4. Include a test report in your merge request

## Review Process

When submitting a merge request:

1. Explain the purpose and functionality of your component
2. Include documentation and examples
3. Reference any related issues
4. Ensure your changes pass CI/CD checks
5. Request review from at least one maintainer

## Versioning

When making changes to existing components:

- **PATCH:** Bug fixes, documentation improvements
- **MINOR:** New features, non-breaking changes
- **MAJOR:** Breaking changes to inputs or behavior

Update the `version` field in the component metadata accordingly.
