---
id: components-bfcicomponents-ci-templates-README
---
# LLM Platform Shared CI/CD Templates

This directory contains shared CI/CD templates for all LLM Platform projects. These templates provide a consistent way to build, test, and deploy LLM Platform applications.

## Usage

To use these templates in your project, add the following to your `.gitlab-ci.yml`:

```yaml
include:
  - project: 'blueflyio/internal-projects/llm/bfcicomponents'
    ref: main
    file: 'ci-templates/shared.yml'
```

## Available Templates

### Job Templates

- `.job_template`: Base template for all jobs
- `.test_template`: Template for test jobs
- `.build_template`: Template for build jobs
- `.deploy_template`: Template for deploy jobs
- `.security_template`: Template for security scanning jobs
- `.performance_template`: Template for performance testing jobs
- `.docs_template`: Template for documentation generation jobs

### Configuration Templates

- `.before_script_template`: Common before_script configuration
- `.after_script_template`: Common after_script configuration
- `.rules_template`: Common rules configuration
- `.cache_template`: Common cache configuration
- `.artifacts_template`: Common artifacts configuration
- `.env_template`: Common environment variables

## Example Usage

Here's an example of how to use these templates in your `.gitlab-ci.yml`:

```yaml
include:
  - project: 'blueflyio/internal-projects/llm/bfcicomponents'
    ref: main
    file: 'ci-templates/shared.yml'

stages:
  - test
  - build
  - deploy

test:
  <<: *test_template
  script:
    - npm run test
    - npm run lint

build:
  <<: *build_template
  script:
    - npm run build

deploy:
  <<: *deploy_template
  environment:
    name: production
    url: https://your-app.bluefly.com
```

## Customization

You can customize any of these templates by overriding specific configurations in your job definitions. For example:

```yaml
test:
  <<: *test_template
  script:
    - npm run test:custom
    - npm run lint:custom
  artifacts:
    paths:
      - custom-coverage/
```

## Requirements

- GitLab CI/CD (self-hosted at gitlab.bluefly.io)
- Node.js 18+
- Docker
- Kubernetes (for deployment)

## Best Practices

1. Always include the shared templates at the top of your `.gitlab-ci.yml`
2. Use the provided templates as a base and customize only what's necessary
3. Keep your pipeline configuration DRY by reusing templates
4. Test your pipeline changes in a feature branch before merging to main
5. Use environment variables for sensitive information

## Support

For questions or issues with these templates, please contact the LLM Platform DevOps team.
