---
title: BFCIComponents
description: Documentation for BFCIComponents
id: components-bfcicomponents
---

# LLM Platform CI/CD Components (BFCIComponents)

## Important URLs

### Repository & CI/CD
- **Repository:** `https://gitlab.com/bluefly-llm/BFCIComponents`
  - Main development branch: `main`
  - Release branch: `release`
- **CI/CD Pipeline:** `https://gitlab.com/bluefly-llm/BFCIComponents/-/pipelines`
- **Package Registry:** `https://gitlab.com/bluefly-llm/BFCIComponents/container_registry`

### Documentation
- **Project Documentation (Local):** `http://localhost:8080/docs/components/bfcicomponents/`
  - Requires BFDOCS to be running (`cd ../BFDOCS && npm run docs:serve`)
- **Component Documentation:**
  - Template Reference: `/templates` directory
  - Script Documentation: `/scripts` directory
  - Pipeline Examples: `/examples` directory
- **Technical Documentation:** Located in `/docs` folder in repository
  - Architecture diagrams
  - Component guides
  - Integration guides
  - Development setup

### Component URLs
- **Template Registry:** `https://gitlab.com/bluefly-llm/BFCIComponents/-/tree/main/templates`
- **Script Registry:** `https://gitlab.com/bluefly-llm/BFCIComponents/-/tree/main/scripts`
- **Example Pipelines:** `https://gitlab.com/bluefly-llm/BFCIComponents/-/tree/main/examples`

### Related Services
- **GitLab Integration:** `https://gitlab.com/bluefly-llm`
  - Pipeline Status: Check individual project pipelines
  - Registry Status: Check container registry status
- **Monitoring Dashboard:** `http://localhost:9090` (if configured)
  - Pipeline Metrics
  - Build Statistics
  - Deployment Status

### Development Tools
- **Test Runner:** Run with `npm test`
- **Template Validation:** `npm run validate`
- **Documentation Generation:** `npm run docs:generate`
- **Local Testing:** `npm run test:local`

### Environment-Specific URLs
- **Development Registry:** `registry-dev.bluefly.ai`
- **Staging Registry:** `registry-staging.bluefly.ai`
- **Production Registry:** `registry.bluefly.ai`

## Quick Start
```bash
# Clone repository
git clone https://gitlab.com/bluefly-llm/BFCIComponents.git

# Install dependencies
npm install

# Set up environment
cp .env.example .env

# Validate templates
npm run validate

# Run tests
npm test
```

For detailed setup instructions, see [Setup Guide](setup).

## Component Development
For information on creating new CI/CD components, see [Component Development Guide](component-development).

## Overview

BFCI Components is a collection of reusable CI/CD components designed to standardize and simplify GitLab pipeline configurations across BlueFly projects. These components provide:

- Standardized build, test, and deployment workflows
- Consistent security scanning and quality checks
- Automated dependency management
- Container image building and publishing

## Getting Started

1. [Installation Guide](./guide/installation)
2. [Basic Configuration](./guide/configuration)
3. [Component Registry](./guide/component-registry)
4. [Usage Examples](./guide/examples)

## Component Reference

Browse our collection of pre-built components:

- [Build Components](./components/build)
- [Test Components](./components/test)
- [Deploy Components](./components/deploy)
- [Security Components](./components/security)

## Project Information

- [Contributing Guidelines](./guide/contributing)
- [Maintenance Guide](./guide/maintenance)
- [Migration Guide](./guide/migration)

## Support

Need help? Check out our [support resources](./guide/support) or [create an issue](https://gitlab.bluefly.io/blueflyio/internal-projects/llm/bfcicomponents/-/issues).

## Quick Links

- [API Reference](./api/README)
- [Technical Documentation](./technical/README)
- [User Guide](./user-guide/README)

## Development

For development guidelines and contribution information, see the [Development Guide](../development/setup).
