---
id: components-bfcicomponents-migrate-from-bfcommon
---
# migrate-from-bfcommon.sh

This script automates the migration from BFCommon CI components to BFCIComponents.

## Overview

The `migrate-from-bfcommon.sh` script is a utility for migrating GitLab CI configurations from using BFCommon CI components to the new BFCIComponents system. It handles:

1. Backing up the original configuration
2. Replacing component references
3. Adding custom Docker image configuration
4. Preserving other configuration settings

## Usage

```bash
./scripts/migrate-from-bfcommon.sh /path/to/project/.gitlab-ci.yml
```

## Migration Process

The script performs these steps:

1. Creates a backup of the original .gitlab-ci.yml file with a .bak extension
2. Replaces all references to BFCommon CI components with their BFCIComponents equivalents:
   - `bfcommon/ci/node-base.yml` → `blueflyio/internal-projects/llm/bfllm-components/nodejs-base@v1.0.0`
   - `bfcommon/ci/node-build.yml` → `blueflyio/internal-projects/llm/bfllm-components/nodejs-build@v1.0.0`
   - `bfcommon/ci/node-test.yml` → `blueflyio/internal-projects/llm/bfllm-components/nodejs-test@v1.0.0`
   - `bfcommon/ci/documentation.yml` → `blueflyio/internal-projects/llm/bfllm-components/documentation@v1.0.0`
   - `bfcommon/ci/model-registry.yml` → `blueflyio/internal-projects/llm/bfllm-components/model-registry@v1.0.0`
3. Adds custom Docker image configuration if not already present

## Example

### Before Migration

```yaml
include:
  - project: 'bluefly/bfcommon'
    file: '/ci/node-base.yml'
    ref: main

  - project: 'bluefly/bfcommon'
    file: '/ci/node-build.yml'
    ref: main

variables:
  NODE_VERSION: '20'
```

### After Migration

```yaml
include:
  - component: 'blueflyio/internal-projects/llm/bfllm-components/nodejs-base@v1.0.0'
    inputs:
      node_version: '20'
      project_type: 'app'
      use_custom_image: true
      custom_image_path: 'registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest'

  - component: 'blueflyio/internal-projects/llm/bfllm-components/nodejs-build@v1.0.0'
    inputs:
      use_custom_image: true
      custom_image_path: 'registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest'

variables:
  NODE_VERSION: '20'
```

## Verifying Migration

After running the migration script, you can verify the results using the `verify-custom-image.sh` script:

```bash
./scripts/verify-custom-image.sh /path/to/project/.gitlab-ci.yml
```

## Handling Special Cases

### Local Dependencies

The migration process doesn't automatically create a `prepare-ci.sh` script for handling local dependencies. If your project uses local dependencies like `"bfcommon": "file:../BFCommon"`, you should create this script manually after migration:

```bash
#!/bin/bash
# Replace local dependencies with published versions for CI environment
sed -i 's|"bfcommon": "file:../BFCommon"|"bfcommon": "1.0.0"|g' package.json
```

Make it executable:

```bash
chmod +x prepare-ci.sh
```

### Custom Job Definitions

The migration script focuses on component include statements. If you have custom job definitions in your CI configuration that explicitly set the `image` property, you may need to update those manually to use the custom Docker image.

## Limitations

1. The script assumes a standard GitLab CI configuration format
2. It does not modify custom job definitions
3. It's a one-way migration (no automatic rollback, though the backup is preserved)

## Troubleshooting

### If Migration Fails

1. Restore from the backup file (.gitlab-ci.yml.bak)
2. Check the error messages
3. Consider migrating manually using the component documentation

### Post-Migration Issues

If your CI pipeline fails after migration:

1. Verify the component inputs match your project's requirements
2. Check for custom job definitions that need to be updated
3. Ensure you have a prepare-ci.sh script if you use local dependencies
