/**
 * Unit tests for the parser module
 */
import { analyzeDocument } from '../../src/parser.js';
import fs from 'fs';
import path from 'path';

// Mock dependencies
jest.mock('fs', () => ({
  promises: {
    readFile: jest.fn(),
    mkdir: jest.fn().mockResolvedValue(undefined),
  },
}));

jest.mock('pdf-parse', () => jest.fn());
jest.mock('../../src/ai-parser.js', () => ({
  aiParseDocument: jest.fn(),
}));

describe('Parser Module', () => {
  beforeEach(() => {
    jest.clearAllMocks();
  });

  test('analyzeDocument should process a text file correctly', async () => {
    // Setup
    const sampleText = 'Sample RFP document text';
    fs.promises.readFile.mockResolvedValue(sampleText);

    // Execute
    const result = await analyzeDocument('test.txt');

    // Verify
    expect(fs.promises.readFile).toHaveBeenCalledWith('test.txt', 'utf8');
    expect(result).toBeDefined();
    expect(result.title).toBeDefined();
  });

  test('analyzeDocument should throw an error for unsupported file types', async () => {
    // Execute & Verify
    await expect(analyzeDocument('test.docx')).rejects.toThrow('Unsupported file type');
  });
});
