---
id: components-bluefly_insights-CLAUDE
---
# CLAUDE.md - LLM Platform Projects Guidelines

## Build/Test/Lint Commands

- `npm run build` - Build TypeScript projects
- `npm run dev` - Run development server with hot reload
- `npm run lint` - Run ESLint checks
- `npm run typecheck` - Verify TypeScript without emitting files
- `npm test` - Run all tests
- `npm test -- -t "test name"` - Run specific test
- `npm run test:watch` - Run tests in watch mode
- `npm run test:integration` - Run integration tests
- `npm run mcp` - Start Model Context Protocol server

## Code Style Guidelines

- **Node.js Version**: Use v20 or above for all projects
- **Module System**: ES Modules with TypeScript, `type: "module"` in package.json
- **Imports**: Order: 1) Node modules 2) External libs 3) Local imports
- **Types**: Use strict TypeScript with interfaces/types for all code
- **Error Handling**: Use `LLM PlatformError` class from BFCommon
- **Naming**: camelCase for variables/functions, PascalCase for classes
- **Formatting**: 2 spaces indentation, semicolons, max 100 chars width
- **Environment**: Use ENV object from BFCommon for config values
- **Exports**: Prefer named exports over default exports
- **Documentation**: JSDoc comments for public APIs and complex functions

## Architecture

- **Shared Code**: Use BFCommon library for utilities across projects
- **TypeScript**: Keep strict mode enabled in tsconfig.json
- **Error Codes**: Use standard error codes from BFCommon
- **Logging**: Use structured logging from BFCommon utilities
- **API Clients**: Use shared API client from BFCommon
- **Testing**: Jest with ESM support via ts-jest

## AI/ML Integration

- Keep AI providers interchangeable with consistent interfaces
- Use model registry for versioning and tracking models
- Standard model name across codebase: `bluefly-rfp-server`
- Cache AI responses when appropriate
- Always validate AI outputs before use
