---
id: components-bluefly_insights-VERSIONING
---
# Versioning and Deployment

LLM Platform Insights follows Drupal's best practices for versioning and deployment. This document explains how version numbers are managed and how releases are created.

## Semantic Versioning

The module follows [Semantic Versioning](https://semver.org/) for version numbers, using the format `MAJOR.MINOR.PATCH`:

- **MAJOR**: Incremented for incompatible API changes or breaking changes to configuration
- **MINOR**: Incremented for new features added in a backward-compatible way
- **PATCH**: Incremented for backward-compatible bug fixes

## Version Information Storage

The module's version is stored in multiple locations to ensure consistency:

1. `bluefly_insights.info.yml` - Primary source of version information for Drupal
2. `composer.json` - Version information for Composer package management
3. `VersionService::VERSION` constant - In-code reference to the version number
4. `CHANGELOG.md` - Complete history of changes for each version

## How Version Numbers Are Updated

Version numbers are automatically updated through semantic-release process:

1. Commits are analyzed based on their commit messages
2. The appropriate version number bump is determined
3. All version files are updated consistently
4. A new entry is added to the CHANGELOG.md file

## Commit Message Format

To ensure proper version management, use the following commit message format:

- `feat: Description` - New feature (triggers MINOR version bump)
- `fix: Description` - Bug fix (triggers PATCH version bump)
- `docs: Description` - Documentation updates (may trigger PATCH)
- `BREAKING CHANGE: Description` - Breaking change (triggers MAJOR version bump)
- `refactor:`, `style:`, `test:`, `chore:` - Other changes (no version bump)

## Drupal Compatibility

The module maintains compatibility with:

- Drupal core versions are specified in the `core_version_requirement` field in the info.yml file
- Dependencies on other modules are specified in both info.yml and composer.json

## Module Installation and Updates

### Installation

1. Install via Composer: `composer require bluefly/bluefly_insights`
2. Enable the module: `drush en bluefly_insights`

### Updates

Updates are handled through Composer:

1. Update the module: `composer update bluefly/bluefly_insights`
2. Run database updates: `drush updatedb`
3. Clear the cache: `drush cache:rebuild`

## Compatibility Checking

Clients can check version compatibility through the module's API:

- `/bluefly_insights/api/version` - Returns the current version and API compatibility level
- `/bluefly_insights/api/compatibility/{version}` - Checks compatibility with a specific version

## Viewing Change History

1. In the admin UI: Navigate to `/admin/config/services/bluefly-insights/changelog`
2. In the filesystem: View the `CHANGELOG.md` file in the module directory

## For Maintainers

When preparing a release:

1. Ensure all changes are properly documented in the code
2. Use the correct commit message formats to trigger appropriate version updates
3. Test the module with the minimum supported Drupal version
4. Verify all dependencies are correctly specified
5. Make sure the CHANGELOG.md is up-to-date and follows the Keep a Changelog format
