---
title: BFAPI
description: Documentation for BFAPI
id: components-bfapi
---

# LLM Platform API Backend (BFAPI)

## Important URLs

### Development URLs
- **Local Development Server:** `http://localhost:3001`
  - Start with `npm run dev`
  - Check `.env` file for actual port configuration
- **API Documentation:** `http://localhost:3001/api-docs`
  - Swagger/OpenAPI documentation when server is running
- **Health Check:** `http://localhost:3001/health`
  - Endpoint to verify API status

### Repository & CI/CD
- **Repository:** `https://gitlab.com/bluefly-llm/BFAPI`
  - Main development branch: `main`
  - Release branch: `release`
- **CI/CD Pipeline:** `https://gitlab.com/bluefly-llm/BFAPI/-/pipelines`
- **Package Registry:** `https://gitlab.com/bluefly-llm/BFAPI/container_registry`

### Documentation
- **Project Documentation (Local):** `http://localhost:8080/docs/components/bfapi/`
  - Requires BFDOCS to be running (`cd ../BFDOCS && npm run docs:serve`)
- **API Reference:** Available at `/docs` endpoint when server is running
- **Technical Documentation:** Located in `/docs` folder in repository
  - Architecture diagrams
  - API specifications
  - Development guides

### Related Services
- **llm-mcp Integration:** `http://localhost:3002` (Model Control Plane)
- **llm-ui Connection:** `http://localhost:3000` (Frontend that consumes this API)
- **Monitoring Dashboard:** `http://localhost:9090` (if Prometheus is configured)

### Environment-Specific URLs
- **Development:** `https://dev-api.bluefly.ai`
- **Staging:** `https://staging-api.bluefly.ai`
- **Production:** `https://api.bluefly.ai`

## Quick Start
```bash
# Clone repository
git clone https://gitlab.com/bluefly-llm/BFAPI.git

# Install dependencies
npm install

# Set up environment
cp .env.example .env

# Start development server
npm run dev
```

For detailed setup instructions, see [Setup Guide](setup).

## Overview

BFRFP is a specialized application for automating and enhancing the RFP (Request for Proposal) response process.

## Getting Started

- [Installation](./getting-started/installation)
- [Configuration](./getting-started/configuration)
- [User Guide](./user/USER_GUIDE)

## API Reference

- [API Documentation](./api/API)

## Technical Documentation

- [AI Integration](./technical/AI_INTEGRATION)

## Quick Links

- [API Reference](./api/README)
- [Technical Documentation](./technical/README)
- [User Guide](./user-guide/README)

## Development

For development guidelines and contribution information, see the [Development Guide](../development/setup).
