---
title: llm-mcp
description: Documentation for llm-mcp
id: components-llm-mcp
---

# LLM Platform Model Control Plane (llm-mcp)

## Important URLs

### Development URLs
- **Local Development Server:** `http://localhost:3002`
  - Start with `npm run dev`
  - Check `.env` file for actual port configuration
- **API Documentation:** `http://localhost:3002/api-docs`
  - Swagger/OpenAPI documentation when server is running
- **Health Check:** `http://localhost:3002/health`
  - Endpoint to verify MCP status
- **Model Status Dashboard:** `http://localhost:3002/dashboard`
  - Real-time model status and metrics

### Repository & CI/CD
- **Repository:** `https://gitlab.com/bluefly-llm/llm-mcp`
  - Main development branch: `main`
  - Release branch: `release`
- **CI/CD Pipeline:** `https://gitlab.com/bluefly-llm/llm-mcp/-/pipelines`
- **Package Registry:** `https://gitlab.com/bluefly-llm/llm-mcp/container_registry`

### Documentation
- **Project Documentation (Local):** `http://localhost:8080/docs/components/llm-mcp/`
  - Requires BFDOCS to be running (`cd ../BFDOCS && npm run docs:serve`)
- **API Reference:** Available at `/docs` endpoint when server is running
- **Technical Documentation:** Located in `/docs` folder in repository
  - Architecture diagrams
  - Model integration guides
  - API specifications
  - Development guides

### Related Services
- **BFAPI Integration:** `http://localhost:3001` (Main API)
- **llm-ui Connection:** `http://localhost:3000` (Frontend that consumes MCP services)
- **Model Monitoring:** `http://localhost:9090` (if Prometheus is configured)
- **Model Metrics Dashboard:** `http://localhost:3002/metrics`

### Environment-Specific URLs
- **Development:** `https://dev-mcp.bluefly.ai`
- **Staging:** `https://staging-mcp.bluefly.ai`
- **Production:** `https://mcp.bluefly.ai`

### Model Endpoints
- **Inference API:** `http://localhost:3002/v1/models/{model_id}/infer`
- **Fine-tuning API:** `http://localhost:3002/v1/models/{model_id}/finetune`
- **Model Management:** `http://localhost:3002/v1/models/manage`
- **Model Registry:** `http://localhost:3002/v1/models/registry`
- **Batch Processing:** `http://localhost:3002/v1/batch`

## Quick Start
```bash
# Clone repository
git clone https://gitlab.com/bluefly-llm/llm-mcp.git

# Install dependencies
npm install

# Set up environment
cp .env.example .env

# Start development server
npm run dev
```

For detailed setup instructions, see [Setup Guide](setup).

## Model Integration
For information on integrating new models, see [Model Integration Guide](model-integration).
