---
id: components-llmcli-DASHBOARD
---
# LLM Platform LLM Dashboard

The LLM Platform LLM Dashboard provides a web-based interface for monitoring and
managing your LLM models, fine-tuning jobs, and model registry. This document
covers the dashboard's features, usage, and troubleshooting.

## Table of Contents

- [Quick Start](#quick-start)
- [Features](#features)
- [Dashboard Interface](#dashboard-interface)
- [Command Line Options](#command-line-options)
- [API Integration](#api-integration)
- [Mock Data Mode](#mock-data-mode)
- [Debug Mode](#debug-mode)
- [Customization](#customization)
- [Troubleshooting](#troubleshooting)
- [Development](#development)

## Quick Start

To start the dashboard:

```bash
# Start the dashboard with default settings
llmcli dashboard start

# Start with a specific port
llmcli dashboard start --port 8080

# Set a custom refresh interval (in seconds)
llmcli dashboard start --refresh 30

# Enable debug mode for development
llmcli dashboard start --debug
```

The dashboard will automatically open in your default browser when started. If
you don't want this behavior, use the `--no-open` flag:

```bash
llmcli dashboard start --no-open
```

## Features

The LLM Platform LLM Dashboard offers:

- **Real-time monitoring** of LLM models and training jobs
- **Service status indicators** showing which backend components are available
- **Automatic fallback to mock data** when backend services are unavailable
- **Responsive design** that works on both desktop and mobile devices
- **Dark mode support** for better visibility in different lighting conditions
- **Auto-refresh** with configurable intervals
- **Debug tools** for development and troubleshooting
- **Keyboard shortcuts** for common operations
- **Robust error handling** with automatic reconnection

## Dashboard Interface

The dashboard is organized into several tabs:

### Available Models

Shows all available LLM models with details including:

- Model ID
- Name
- Type
- Version
- Status

### Fine-tuned Models

Displays models that have been fine-tuned:

- Model ID
- Name
- Base Model
- Creation Date
- Status

### Training Jobs

Lists all training jobs with their status:

- Job ID
- Base Model
- Status (pending, running, completed, failed)
- Progress percentage
- Creation date

### Model Registry

Shows all models in the registry:

- Model ID
- Name
- Version
- Type
- Source location

### Model Details

Clicking the "Details" button for any model will show additional information:

- All model properties
- Metadata (if available)
- Training metrics (for fine-tuned models)

## Command Line Options

The dashboard command supports several options:

| Option                    | Description                          | Default |
| ------------------------- | ------------------------------------ | ------- |
| `-p, --port <port>`       | Port to run the dashboard on         | 3456    |
| `--no-open`               | Do not open the dashboard in browser | false   |
| `-r, --refresh <seconds>` | Data refresh interval in seconds     | 10      |
| `-d, --debug`             | Enable debug mode                    | false   |

## API Integration

The dashboard integrates with several backend APIs:

- **Model API**: For retrieving available models
- **Fine-tuning API**: For managing fine-tuned models and training jobs
- **Registry API**: For accessing the model registry

When these services are unavailable, the dashboard automatically falls back to
mock data mode.

## Mock Data Mode

When backend services are unavailable, the dashboard operates in mock data mode:

- A "Using Mock Data" indicator appears in the UI
- Sample models, fine-tuned models, and jobs are displayed
- Write operations (like canceling jobs) will not work

This mode is useful for:

- Development and testing
- Demonstration purposes
- When backend services are down or unreachable

## Debug Mode

Debug mode provides additional tools for development and troubleshooting:

1. Start the dashboard with the `--debug` flag:

   ```bash
   llmcli dashboard start --debug
   ```

2. A debug toolbar will appear in the UI with options to:
   - Modify refresh interval
   - Force data refresh
   - Test error notifications
   - Disconnect/reconnect the WebSocket
   - View an event log

## Customization

### Changing the Appearance

The dashboard supports dark mode, which can be toggled using the theme button
(🌓) in the bottom-right corner.

### Modifying Refresh Intervals

You can change how often the dashboard refreshes data:

1. Command line: `llmcli dashboard start --refresh 30` (refresh every 30 seconds)
2. In debug mode: Use the refresh interval input in the debug toolbar

## Troubleshooting

### Dashboard Shows "Loading..." Indefinitely

**Cause**: The dashboard cannot connect to the backend services or is
experiencing WebSocket issues.

**Solutions**:

1. Check that required services are running
2. Ensure there are no network issues
3. Restart the dashboard
4. Check browser console for errors

### "Port Already in Use" Error

**Cause**: Another process (possibly another dashboard instance) is using the
specified port.

**Solutions**:

1. Use a different port: `llmcli dashboard start --port 3457`
2. Stop the existing process and restart
3. Choose "y" when prompted to stop the existing dashboard

### No Data Appears After Connection

**Cause**: Backend API services are not responding correctly.

**Solutions**:

1. Check that all required backend services are running
2. Look for errors in the service logs
3. The dashboard will fall back to mock data if services are unavailable

## Development

The dashboard is built with:

- **Express**: Backend server
- **Socket.IO**: Real-time updates
- **Bootstrap**: UI components
- **Chart.js**: Data visualization

### Directory Structure

```
llmcli/
├── dashboard/          # Dashboard client files
│   ├── index.html      # Main HTML template
│   ├── dashboard.js    # Client-side JavaScript
│   └── styles.css      # CSS styles
└── src/
    └── commands/
        └── dashboard.js # Dashboard server implementation
```

### Adding New Features

To extend the dashboard:

1. Modify the dashboard server (llmcli/src/commands/dashboard.js)
2. Update the client interface (llmcli/dashboard/dashboard.js)
3. Add any necessary styles (llmcli/dashboard/styles.css)

### Testing Changes

Run the dashboard in debug mode to test your changes:

```bash
llmcli dashboard start --debug
```
