---
id: components-llmcli-DEPLOYMENT
---
# Deployment Guide

## Overview

This document outlines the deployment process for the LLM Platform LLM ecosystem. The
deployment is managed through the llmcli tool, which provides a standardized
workflow for all projects.

## Prerequisites

- Node.js 18+
- npm 9+
- Python 3.8+ (for BFLLM)
- DDEV (for Drupal projects)
- Docker and Docker Compose

## Deployment Process

### 1. Setup

Before deploying, ensure all projects have the shared configuration:

```bash
npm run setup
```

### 2. Testing

Run tests for all projects:

```bash
npm test
```

### 3. Deployment

Deploy all projects using the llmcli:

```bash
npm run deploy
```

Or deploy a specific project:

```bash
npm run deploy -- --project=llm-mcp
```

## Project-Specific Deployment

### Node.js Projects (llm-mcp, BFAPI, BFRFP, BFCIComponents)

1. Tests are run using Jest
2. Build process uses npm scripts
3. Deployment is handled by project-specific deploy.sh scripts

### Python Project (BFLLM)

1. Tests are run using pytest
2. Build process uses setup.py
3. Deployment is handled by project-specific deploy.sh script

### Drupal Projects (llm-ui, bluefly_insights)

1. Tests are run using PHPUnit
2. Build process uses Composer
3. Deployment uses DDEV and Drush

## Environment Configuration

Each project should have its own `.env` file with the following structure:

```
NODE_ENV=production
API_URL=https://api.bluefly.com
MCP_SERVER_URL=https://mcp.bluefly.com
```

## Monitoring

After deployment, monitor the following:

1. Application logs
2. Error rates
3. Performance metrics
4. Resource utilization

## Rollback Procedure

If deployment fails:

1. Identify the failing project
2. Run the rollback script:

```bash
npm run deploy -- --rollback --project=<project-name>
```

## Troubleshooting

Common issues and solutions:

1. **Build Failures**: Check node_modules and package-lock.json
2. **Test Failures**: Review test logs and fix failing tests
3. **Deployment Errors**: Check environment variables and network connectivity
4. **Drupal Issues**: Run `ddev drush cr` to clear caches

## Security Considerations

1. All sensitive data must be in environment variables
2. API keys and secrets must be properly secured
3. Follow the principle of least privilege
4. Regular security audits and updates

## Maintenance

1. Regular dependency updates
2. Security patches
3. Performance optimization
4. Documentation updates
