---
id: components-llmcli-commands
---
# llmcli Command Reference

## Project Management Commands

### `bf init <project-name>`

Initialize a new LLM Platform project.

**Example:**

```bash
bf init my-ai-project
```

**Description:**
Creates a new project directory with the necessary configuration files and structure.

### `bf add <component-type> <component-name>`

Add a new component to the project.

**Example:**

```bash
bf add service user-authentication
```

**Description:**
Generates boilerplate code for a new component based on the specified type.

### `bf list`

List all components in the project.

**Example:**

```bash
bf list
```

**Description:**
Displays a table of all components with their types and status.

## Development Commands

### `bf dev`

Start the development server.

**Example:**

```bash
bf dev
```

**Description:**
Starts the development server with hot reloading and debugging enabled.

### `bf test`

Run project tests.

**Example:**

```bash
bf test
```

**Description:**
Executes all tests in the project, including unit, integration, and end-to-end tests.

### `bf build`

Build the project for production.

**Example:**

```bash
bf build
```

**Description:**
Compiles and bundles the project for production deployment.

### `bf docs`

Generate project documentation.

**Example:**

```bash
bf docs
```

**Description:**
Generates documentation for all components and APIs in the project.

## Deployment Commands

### `bf deploy <environment>`

Deploy the project to the specified environment.

**Example:**

```bash
bf deploy staging
```

**Description:**
Deploys the current version of the project to the specified environment.

### `bf rollback <version>`

Rollback to a previous version.

**Example:**

```bash
bf rollback v1.2.3
```

**Description:**
Reverts the deployment to the specified version.

## AI Integration Commands

### `bf train <model-name>`

Train a new AI model.

**Example:**

```bash
bf train sentiment-analysis
```

**Description:**
Initiates the training process for a new AI model with the specified name.

### `bf deploy-model <model-name>`

Deploy an AI model.

**Example:**

```bash
bf deploy-model sentiment-analysis
```

**Description:**
Deploys the specified model to the production environment.

### `bf monitor <model-name>`

Monitor model performance.

**Example:**

```bash
bf monitor sentiment-analysis
```

**Description:**
Displays real-time performance metrics for the specified model.

## Documentation Commands

### `bf docs:api`

Generate API documentation.

**Example:**

```bash
bf docs:api
```

**Description:**
Generates OpenAPI documentation for all API endpoints.

### `bf docs:component <component-name>`

Generate component documentation.

**Example:**

```bash
bf docs:component user-authentication
```

**Description:**
Generates documentation for the specified component.

### `bf docs:serve`

Serve documentation locally.

**Example:**

```bash
bf docs:serve
```

**Description:**
Starts a local server to view the generated documentation.

## Utility Commands

### `bf config`

Display or update configuration.

**Example:**

```bash
bf config
```

**Description:**
Shows the current configuration or allows updating specific settings.

### `bf version`

Display version information.

**Example:**

```bash
bf version
```

**Description:**
Shows the current version of llmcli and installed components.

### `bf help`

Display help information.

**Example:**

```bash
bf help
```

**Description:**
Shows available commands and their usage.

## Environment Management

### `bf env list`

List available environments.

**Example:**

```bash
bf env list
```

**Description:**
Displays all configured deployment environments.

### `bf env create <name>`

Create a new environment.

**Example:**

```bash
bf env create production
```

**Description:**
Creates a new deployment environment with the specified name.

### `bf env delete <name>`

Delete an environment.

**Example:**

```bash
bf env delete staging
```

**Description:**
Removes the specified environment configuration.

## Security Commands

### `bf security scan`

Run security scan.

**Example:**

```bash
bf security scan
```

**Description:**
Performs a security scan of the project dependencies and code.

### `bf security audit`

Run security audit.

**Example:**

```bash
bf security audit
```

**Description:**
Conducts a comprehensive security audit of the project.

## Performance Commands

### `bf perf test`

Run performance tests.

**Example:**

```bash
bf perf test
```

**Description:**
Executes performance tests and generates a report.

### `bf perf monitor`

Monitor performance metrics.

**Example:**

```bash
bf perf monitor
```

**Description:**
Displays real-time performance metrics for the running application.

## Database Commands

### `bf db migrate`

Run database migrations.

**Example:**

```bash
bf db migrate
```

**Description:**
Applies pending database migrations.

### `bf db seed`

Seed the database.

**Example:**

```bash
bf db seed
```

**Description:**
Populates the database with initial data.

## Logging Commands

### `bf logs`

View application logs.

**Example:**

```bash
bf logs
```

**Description:**
Displays the application logs in real-time.

### `bf logs export`

Export logs to file.

**Example:**

```bash
bf logs export
```

**Description:**
Exports the application logs to a file for analysis.
