---
title: llmcli
description: Documentation for llmcli
id: components-llmcli
---

# LLM Platform Command Line Interface (llmcli)

**Status**: ✅ Production Ready - Complete CLI with platform installation support  
**Location**: `/LLM/_CommonNPM/llmcli/`  
**Technology**: Node.js + TypeScript + Commander.js

## Key Features

### Platform Installation
- **`llm platform:install`** - Complete LLM platform installation with all components
- **Vector Database Support** - Optional Milvus/vector database installation
- **AI Services Setup** - Configurable AI provider installation
- **Drupal Integration** - Full Drupal 10/11 platform setup

### Service Management
- **Service Orchestration** - Start, stop, and monitor platform services
- **Worker Management** - Distributed AI processing workers
- **Configuration** - Environment setup and validation
- **Monitoring** - Real-time metrics and health checks

## Installation & Quick Start

```bash
# Install CLI
npm install -g @llm-platform/cli

# Install complete LLM platform
llmcli llm platform:install --with-vector-db --with-ai-services

# Initialize new project
llmcli llm init my-project --template advanced

# Check platform status
llmcli system status
```

## Repository & CI/CD
- **Repository:** `https://gitlab.com/llm-platform/llmcli`
- **Package:** `@llm-platform/cli`

### Documentation
- **Project Documentation (Local):** `http://localhost:8080/docs/components/llmcli/`
  - Requires BFDOCS to be running (`cd ../BFDOCS && npm run docs:serve`)
- **CLI Documentation:**
  - Run `llmcli --help` for command list
  - Run `llmcli <command> --help` for specific command help
- **Technical Documentation:** Located in `/docs` folder in repository
  - Architecture diagrams
  - Command reference
  - Plugin development guide
  - Development setup guide

### Related Services
- **llm-gateway Integration:** `http://localhost:3001` (API Gateway)
- **llm-mcp Integration:** `http://localhost:3002` (Model Control Plane)
- **Monitoring Dashboard:** `http://localhost:9090` (if configured)

### Development Tools
- **Test Runner:** Run with `npm test`
- **Coverage Report:** Generate with `npm run test:coverage`
- **Documentation Generation:** `npm run docs:generate`
- **TypeScript Compilation:** `npm run build`

### Package URLs
- **NPM Registry:** `https://www.npmjs.com/package/@llm-platform/cli`
- **Documentation Site:** `https://docs.llm-platform.ai/cli`

## Quick Start
```bash
# Install globally
npm install -g @bluefly/cli

# Or clone repository for development
git clone https://gitlab.com/bluefly-llm/llmcli.git
cd llmcli
npm install

# Set up environment
cp .env.example .env

# Build the CLI
npm run build

# Link for local development
npm link

# Run CLI
llmcli --help
```

For detailed setup instructions, see [Setup Guide](setup).

## Command Development
For information on creating new commands, see [Command Development Guide](command-development).

## Overview

llmcli is a command-line interface that provides access to all features of the
LLM Platform LLM ecosystem. It enables developers and users to interact with models,
analyze documents, generate RFP responses, and manage development workflows
through a unified CLI.

## Documentation Sections

- [API Reference](./api/index) - Public API for programmatic usage
- [Technical Documentation](./technical/index) - Implementation details and
  architecture
- [User Guide](./user/index) - Usage instructions and examples

## Quick Navigation

| Section                                       | Description              |
| --------------------------------------------- | ------------------------ |
| [Installation](../README.md#installation)     | How to install llmcli     |
| [Usage](../README.md#usage)                   | Basic usage instructions |
| [Command Groups](../README.md#command-groups) | Available command groups |
| [Development](../README.md#development)       | Development guidelines   |

## Contributing to Documentation

All documentation for llmcli is maintained in the llmcli repository and
synchronized with the central documentation hub. To contribute to this
documentation:

1. Make changes directly to the markdown files in the `docs/` directory
2. Submit a merge request with your changes
3. After approval, changes will be synchronized to the central documentation hub

For documentation guidelines, see the
[Documentation Workflow Guide](https://gitlab.bluefly.io/blueflyio/internal-projects/llm/bfdocs/blob/main/docs/guides/documentation-workflow)
in the BFDOCS repository.

## Quick Links

- [API Reference](./api/README)
- [Technical Documentation](./technical/README)
- [User Guide](./user-guide/README)

## Getting Started

For installation and setup instructions, see the [Getting Started Guide](../getting-started/installation).

## Development

For development guidelines and contribution information, see the [Development Guide](../development/setup).
