---
id: components-llmcli-monitoring
---
# llmcli Monitoring Commands

The llmcli provides comprehensive system monitoring capabilities through the `monitor` command. This command allows you to monitor various aspects of your system including resources, performance metrics, system health, services, and network traffic.

## Overview

The monitoring system is built with the following key features:
- Real-time monitoring of system resources
- Performance metrics tracking with customizable thresholds
- System health checks
- Service-specific monitoring
- Network traffic analysis
- Configurable alert notifications

## Commands

### Monitor Resources

Monitor system resources including CPU, memory, disk, and network usage.

```bash
llmcli monitor resources [options]

Options:
  --interval <seconds>  Set monitoring interval (default: 5)
  --metrics <list>      Comma-separated list of metrics to monitor
  --alert              Enable alerts for threshold violations
```

Example:
```bash
# Monitor all resources with 10-second interval
llmcli monitor resources --interval 10

# Monitor specific metrics
llmcli monitor resources --metrics cpu,memory --alert
```

### Monitor Performance

Track performance metrics with customizable thresholds.

```bash
llmcli monitor performance [options]

Options:
  --interval <seconds>     Set monitoring interval (default: 5)
  --metrics <list>        Comma-separated list of metrics to monitor
  --threshold <json>      JSON string of threshold configurations
  --alert                Enable threshold alerts
```

Example:
```bash
# Monitor performance with custom thresholds
llmcli monitor performance --threshold '{"cpu":90,"memory":85}'

# Monitor specific metrics with alerts
llmcli monitor performance --metrics cpu,disk --alert
```

### System Health

Monitor overall system health and component status.

```bash
llmcli monitor health [options]

Options:
  --interval <seconds>  Set monitoring interval (default: 5)
  --detailed           Show detailed health information
  --components <list>  Comma-separated list of components to monitor
```

Example:
```bash
# Monitor system health with detailed information
llmcli monitor health --detailed

# Monitor specific components
llmcli monitor health --components disk,network
```

### Service Monitoring

Monitor specific services and their metrics.

```bash
llmcli monitor service <service-name> [options]

Options:
  --interval <seconds>  Set monitoring interval (default: 5)
  --metrics <list>     Comma-separated list of metrics to monitor
  --alert             Enable service alerts
```

Example:
```bash
# Monitor a specific service
llmcli monitor service nginx --metrics cpu,memory

# Monitor service with alerts
llmcli monitor service postgresql --alert
```

### Network Monitoring

Monitor network traffic and connections.

```bash
llmcli monitor network [options]

Options:
  --interface <name>   Network interface to monitor
  --protocol <type>    Protocol to monitor (tcp/udp)
  --filter <expr>      Packet filter expression
  --interval <seconds> Set monitoring interval (default: 5)
```

Example:
```bash
# Monitor specific network interface
llmcli monitor network --interface eth0

# Monitor with protocol filter
llmcli monitor network --protocol tcp --filter "port 80"
```

## Configuration

The monitoring system can be configured through the `monitoring.json` file in your project's config directory. This file allows you to set default values for:

- Monitoring intervals
- Alert thresholds
- Notification settings
- Metrics to collect
- Log levels and formats

Example configuration:
```json
{
  "metrics": {
    "cpu": {
      "enabled": true,
      "threshold": 90,
      "interval": 5
    },
    "memory": {
      "enabled": true,
      "threshold": 85,
      "interval": 5
    }
  },
  "alerts": {
    "email": {
      "enabled": true,
      "recipients": ["admin@example.com"]
    },
    "slack": {
      "enabled": true,
      "webhook": "${SLACK_WEBHOOK_URL}"
    }
  }
}
```

## Alert Notifications

The monitoring system can send alerts through various channels when thresholds are exceeded:

- Email notifications
- Slack messages
- System logs
- Custom webhook integrations

To configure alert notifications, update the alerts section in your `monitoring.json` file.

## Best Practices

1. Start with default thresholds and adjust based on your system's characteristics
2. Use appropriate monitoring intervals to balance accuracy and system load
3. Configure alerts for critical metrics only to avoid alert fatigue
4. Regularly review and update monitoring configurations
5. Use detailed mode sparingly as it increases system load

## Troubleshooting

Common issues and their solutions:

1. High CPU usage during monitoring
   - Increase monitoring intervals
   - Reduce the number of monitored metrics
   - Use selective monitoring instead of monitoring everything

2. Missing metrics
   - Check if the required system tools are installed
   - Verify permissions for accessing system metrics
   - Check if the service being monitored is running

3. Alert notification issues
   - Verify notification configuration
   - Check network connectivity
   - Ensure webhook URLs are correct and accessible 
