---
id: components-llmcli-user
---
# llmcli User Guide

This guide provides detailed instructions on how to use the LLM Platform Command Line
Interface (llmcli) effectively.

## Installation

### Global Installation

```bash
# Using npm
npm install -g llmcli

# Using yarn
yarn global add llmcli
```

### Local Installation

```bash
# Clone the repository
git clone https://gitlab.com/bluefly/llmcli.git
cd llmcli

# Install dependencies
npm install

# Link for local development
npm link
```

## Configuration

After installation, configure your llmcli:

```bash
# Set API endpoint
llmcli config set apiUrl https://api.bluefly.io

# Set API key
llmcli config set apiKey your-api-key-here

# View current configuration
llmcli config list
```

## Command Groups

llmcli organizes commands into logical groups:

### Model Commands

For working with AI models:

```bash
# List available models
llmcli model list

# Get model details
llmcli model get model-id

# Generate content with a model
llmcli model generate model-id "Your prompt here"
```

### Analyze Commands

For document analysis:

```bash
# Analyze an RFP document
llmcli analyze rfp path/to/document.pdf

# Extract specific information
llmcli analyze entities path/to/document.pdf

# View analysis history
llmcli analyze history
```

### Generate Commands

For content generation:

```bash
# Generate RFP response
llmcli generate response analysis-id output.md

# Generate specific section
llmcli generate section technical-approach

# List available templates
llmcli generate list-templates
```

### Dev Commands

For development workflows:

```bash
# Status across all projects
llmcli dev status-all

# Pull changes across all projects
llmcli dev pull-all

# Install dependencies across all projects
llmcli dev install-all
```

### Resource Commands

For resource management:

```bash
# List team members
llmcli resource list-team

# Create project quote
llmcli resource create-quote project-name requirements.json team.json labor.json
```

## Common Workflows

### RFP Response Workflow

1. Analyze the RFP document:

   ```bash
   llmcli analyze rfp rfp-document.pdf
   ```

2. Generate a response using the analysis:

   ```bash
   llmcli generate response analysis-id response.md
   ```

3. Export the response to the desired format:
   ```bash
   llmcli generate export response.md final-response.docx
   ```

### Development Workflow

```bash
# Check status of all projects
llmcli dev status-all

# Pull latest changes for all projects
llmcli dev pull-all

# Push changes for all projects
llmcli dev push-all
```

### GitLab Workflow

The workflow command group integrates with GitLab's CLI (glab) to provide a
streamlined workflow for managing projects in GitLab.

#### Prerequisites

Before using the workflow commands, ensure GitLab CLI is installed. llmcli will
attempt to install it if not found.

```bash
# Set up workflow for all projects
llmcli workflow setup-all
```

#### Working with Merge Requests

```bash
# Create a merge request
llmcli workflow mr-create --project BFLLM --title "Feature: Add new model" --description "Adds support for a new model" --source feature-branch --target main

# List merge requests
llmcli workflow mr-list --project BFLLM --state opened

# Update a merge request
llmcli workflow mr-update 123 --project BFLLM --title "Updated title"

# Merge a merge request
llmcli workflow mr-merge 123 --project BFLLM --delete-branch

# Close a merge request
llmcli workflow mr-close 123 --project BFLLM
```

#### Working with Pipelines

```bash
# Run a pipeline
llmcli workflow pipeline-run --project BFLLM --branch main --variables '{"VARIABLE1":"value1","VARIABLE2":"value2"}'

# List pipelines
llmcli workflow pipeline-list --project BFLLM --status running
```

#### Working with Issues and Releases

```bash
# Create an issue
llmcli workflow issue-create --project BFLLM --title "Bug: Fix memory leak" --description "There's a memory leak in the model loading code"

# Create a release
llmcli workflow release-create --project BFLLM --tag v1.0.0 --name "Version 1.0.0" --description "Initial release"
```

## Advanced Usage

### Custom Output Formats

```

```
