---
id: composer_names_to_fix
---
# Composer Package Naming Compliance

## Custom Modules Requiring Updates

The following custom modules need their composer.json `name` field updated to follow the naming convention:
- Start with `bluefly/` namespace
- Use underscores (_) instead of hyphens (-) in package names

### Priority Modules to Fix

1. **drupal_migration_plus**
   - Current: `custom/drupal_migration_plus`
   - Should be: `bluefly/drupal_migration_plus`
   - Path: `./_DrupalModules/drupal_migration_plus/composer.json`

2. **marketplace_integration**
   - Current: `drupal/marketplace_integration`
   - Should be: `bluefly/marketplace_integration`
   - Path: `./_DrupalModules/marketplace_integration/composer.json`

3. **multitenancy**
   - Current: `drupal/multitenancy`
   - Should be: `bluefly/multitenancy`
   - Path: `./_DrupalModules/multitenancy/composer.json`

4. **recipe_onboarding**
   - Current: `drupal/recipe_onboarding`
   - Should be: `bluefly/recipe_onboarding`
   - Path: `./_DrupalModules/recipe_onboarding/composer.json`

### Modules to Ignore

The following modules should NOT be modified as they are test fixtures, contrib modules, or third-party code:

1. All files within:
   - `./_DrupalModules/drupal_migration_plus/core/`
   - `./_DrupalModules/drupal_migration_plus/modules/migrate_plus/`
   - Any fixtures or test modules

## How to Fix

Run the script with the `--fix` option specifically targeting your custom modules:

```bash
# Fix a specific custom module
php check_composer_names.php --fix ./_DrupalModules/marketplace_integration

# Fix all custom modules that need updates (CAREFUL - validate paths first)
php check_composer_names.php --fix --verbose ./_DrupalModules/drupal_migration_plus/composer.json
php check_composer_names.php --fix --verbose ./_DrupalModules/marketplace_integration
php check_composer_names.php --fix --verbose ./_DrupalModules/multitenancy
php check_composer_names.php --fix --verbose ./_DrupalModules/recipe_onboarding
```

## Validation

After making changes, run the script again without the `--fix` option to verify that all issues have been resolved:

```bash
php check_composer_names.php --verbose ./_DrupalModules
```

## Integration into CI

To enforce this naming convention in your CI pipeline, add the following step to your GitLab CI configuration:

```yaml
validate_composer_names:
  stage: validate
  script:
    - php check_composer_names.php
  rules:
    - if: '$CI_PIPELINE_SOURCE == "merge_request_event"'
    - if: '$CI_COMMIT_BRANCH == "main"'
```

This will ensure that all composer.json files comply with your naming standards before merging to main.
