---
id: database_schemas-llm_platform_schema
---
# LLM Platform Database Schema Diagram

```mermaid
erDiagram
    MODELS {
        int id PK
        varchar(100) name
        varchar(50) provider
        varchar(100) base_model
        text description
        json capabilities
        timestamp created_at
        timestamp updated_at
        boolean is_active
    }
    
    MODEL_VERSIONS {
        int id PK
        int model_id FK
        varchar(50) version
        bigint parameters
        int context_window
        decimal(10,6) input_token_cost
        decimal(10,6) output_token_cost
        timestamp created_at
        timestamp updated_at
        boolean is_default
    }
    
    MODELS ||--o{ MODEL_VERSIONS : has
```

## Table Relationships

- **Models to ModelVersions**: One-to-Many relationship. A model can have multiple versions, but each version belongs to exactly one model.

## Primary Key Strategy

- Both tables use auto-incrementing integer primary keys for simplicity and performance.
- The ModelVersions table has a composite unique constraint on (model_id, version) to ensure version uniqueness within a model.

## Indexing Strategy

### Models Table
- Primary Key: `id`
- Unique Index: `name` - For quick lookup by model name
- Index: `provider` - For filtering by provider
- Index: `base_model` - For filtering by base model
- Index: `is_active` - For filtering active models

### ModelVersions Table
- Primary Key: `id`
- Foreign Key: `model_id` - References Models table
- Unique Index: `(model_id, version)` - Ensures unique versions per model
- Index: `is_default` - For filtering default versions

## Data Types and Constraints

- **JSON Column**: The `capabilities` column uses the JSON data type for flexible storage of model capabilities.
- **Timestamps**: Both tables include `created_at` and `updated_at` timestamps with automatic update functionality.
- **Decimal Precision**: Token costs use DECIMAL(10,6) for precise cost calculations.
- **Foreign Key Constraints**: CASCADE deletion ensures referential integrity.

## Query Optimization

The schema is optimized for the following common query patterns:
- Finding models by provider
- Looking up active models
- Retrieving default versions of models
- Filtering models by capabilities
- Finding models with specific context window sizes

For additional query examples, see the [query_examples.sql](query_examples.sql) file.
