#!/bin/bash
# LLM Platform Database Deployment Script
# This script runs the database migration files in the correct order

# Configuration - update these variables
DB_USER="root"
DB_PASS="password"
DB_NAME="llm_platform"
DB_HOST="localhost"

# Display script header
echo "===================================="
echo "LLM Platform Database Deployment"
echo "===================================="
echo "Database: $DB_NAME"
echo "Host: $DB_HOST"
echo "===================================="

# Function to run a SQL file
run_sql_file() {
    echo "Running migration: $1"
    mysql -h "$DB_HOST" -u "$DB_USER" -p"$DB_PASS" "$DB_NAME" < "$1"
    
    if [ $? -eq 0 ]; then
        echo "✅ Successfully executed $1"
    else
        echo "❌ Error executing $1"
        exit 1
    fi
}

# Check if database exists, create if it doesn't
echo "Checking if database exists..."
DB_EXISTS=$(mysql -h "$DB_HOST" -u "$DB_USER" -p"$DB_PASS" -e "SHOW DATABASES LIKE '$DB_NAME';" | grep "$DB_NAME" > /dev/null; echo "$?")

if [ $DB_EXISTS -ne 0 ]; then
    echo "Creating database $DB_NAME..."
    mysql -h "$DB_HOST" -u "$DB_USER" -p"$DB_PASS" -e "CREATE DATABASE $DB_NAME CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;"
    
    if [ $? -eq 0 ]; then
        echo "✅ Database created successfully"
    else
        echo "❌ Failed to create database"
        exit 1
    fi
else
    echo "✅ Database already exists"
fi

# Get directory of this script
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

# Run migrations in order
echo "Starting migrations..."
run_sql_file "$DIR/01_create_llm_platform_tables.sql"
run_sql_file "$DIR/02_insert_sample_data.sql"

# Verify migration
echo "Verifying migration..."
MODEL_COUNT=$(mysql -h "$DB_HOST" -u "$DB_USER" -p"$DB_PASS" -e "SELECT COUNT(*) FROM $DB_NAME.models;" -sN)
VERSION_COUNT=$(mysql -h "$DB_HOST" -u "$DB_USER" -p"$DB_PASS" -e "SELECT COUNT(*) FROM $DB_NAME.model_versions;" -sN)

echo "Models table has $MODEL_COUNT records"
echo "ModelVersions table has $VERSION_COUNT records"

echo "===================================="
echo "✅ Database deployment complete!"
echo "===================================="

# Make the script executable with: chmod +x deploy_database.sh