---
title: LLM Platform Documentation Hub
description: Comprehensive documentation aggregated from all LLM Platform projects
---

# LLM Platform Documentation Hub

Welcome to the comprehensive documentation for the LLM Platform ecosystem. This documentation is automatically aggregated from all platform components.

## 📦 NPM Packages (9)

- **[apple-fm](/packages/apple-fm/)** - ✅ Production Ready
  - Repository: [GitLab](https://gitlab.bluefly.io/llm/apple-fm)
- **[bfrfp](/packages/bfrfp/)** - ✅ Production Ready
  - Repository: [GitLab](https://gitlab.bluefly.io/llm/bfrfp)
- **[llm-gateway](/packages/llm-gateway/)** - 🚀 Feature Complete
  - Repository: [GitLab](https://gitlab.bluefly.io/llm/llm-gateway)
- **[llm-gateway-sdk](/packages/llm-gateway-sdk/)** - 🚀 Feature Complete
  - Repository: [GitLab](https://gitlab.bluefly.io/llm/llm-gateway-sdk)
- **[llm-mcp](/packages/llm-mcp/)** - 🚀 Feature Complete
  - Repository: [GitLab](https://gitlab.bluefly.io/llm/llm-mcp)
- **[llm-ui](/packages/llm-ui/)** - 🚀 Feature Complete
  - Repository: [GitLab](https://gitlab.bluefly.io/llm/llm-ui)
- **[llmcli](/packages/llmcli/)** - 🚀 Feature Complete
  - Repository: [GitLab](https://gitlab.bluefly.io/llm/llmcli)
- **[tddai](/packages/tddai/)** - ✅ Production Ready
  - Repository: [GitLab](https://gitlab.bluefly.io/llm/tddai)
- **[secure-project](/packages/secure-project/)** - 🚀 Feature Complete
  - Repository: [GitLab](https://gitlab.bluefly.io/llm/secure-project)

## 🤖 AI Models (1)

- **[tddai-model](/models/tddai-model/)** - Production AI model with MLflow integration
  - Repository: [GitLab](https://gitlab.bluefly.io/llm/models/tddai-model)

## 🔧 CI/CD Components (1)

- **[bfcicomponents](/cicd/bfcicomponents/)** - GitLab CI/CD component catalog
  - Repository: [GitLab](https://gitlab.bluefly.io/llm/bfcicomponents)

## 🚀 Quick Start

```bash
# Install LLM Platform CLI
npm install -g @llm-platform/cli

# Install complete platform with all components
llmcli llm platform:install --with-vector-db --with-ai-services

# Initialize new project
llmcli llm init my-project --template advanced
```

## 🏗️ Platform Architecture

The LLM Platform follows a modular architecture with independent NPM packages:

```
┌─────────────────────────────────────────────────────────┐
│                   CLI Interface                          │
│                   llmcli                                │
└─────────────────┬───────────────────────────────────────┘
                  │
┌─────────────────▼───────────────────────────────────────┐
│                API Gateway                               │
│              llm-gateway                                │
└─────────────────┬───────────────────────────────────────┘
                  │
┌─────────────────▼───────────────────────────────────────┐
│                Service Layer                             │
│  apple-fm │ bfrfp │ llm-mcp │ tddai │ llm-ui          │
└─────────────────┬───────────────────────────────────────┘
                  │
┌─────────────────▼───────────────────────────────────────┐
│              CI/CD Pipeline                              │
│              bfcicomponents                             │
└─────────────────────────────────────────────────────────┘
```

## 📚 Documentation Organization

This documentation hub automatically aggregates content from:

- **Individual project `/docs` folders** - Detailed technical documentation
- **README.md files** - Project overviews and quick start guides  
- **Package.json metadata** - Dependency and script information
- **GitLab repository links** - Source code and issue tracking

## 🔗 Project Repositories

All projects are hosted on GitLab at: **https://gitlab.bluefly.io/llm/**

- [apple-fm](https://gitlab.bluefly.io/llm/apple-fm)
- [bfrfp](https://gitlab.bluefly.io/llm/bfrfp)
- [llm-gateway](https://gitlab.bluefly.io/llm/llm-gateway)
- [llm-gateway-sdk](https://gitlab.bluefly.io/llm/llm-gateway-sdk)
- [llm-mcp](https://gitlab.bluefly.io/llm/llm-mcp)
- [llm-ui](https://gitlab.bluefly.io/llm/llm-ui)
- [llmcli](https://gitlab.bluefly.io/llm/llmcli)
- [tddai](https://gitlab.bluefly.io/llm/tddai)
- [secure-project](https://gitlab.bluefly.io/llm/secure-project)
- [tddai-model](https://gitlab.bluefly.io/llm/models/tddai-model)
- [bfcicomponents](https://gitlab.bluefly.io/llm/bfcicomponents)

---

**Last Updated**: 2025-06-24 | **Projects**: 11 | **Status**: Active Development

*This documentation is automatically synchronized with all LLM Platform projects.*
