---
id: modules-development-langchain-DRUPAL_ORG_PAGE
---
# LangChain

## Overview

The LangChain module brings LangChain-style agent orchestration and LLM workflow integration to Drupal, enabling advanced AI pipelines and composable agent systems. This module serves as a bridge between Drupal and the growing ecosystem of AI/ML tools and services.

## Features

### LLM Integration

- Support for multiple LLM providers (OpenAI, HuggingFace, etc.)
- Unified interface for interacting with different AI models
- Configurable model settings and parameters
- Secure API key management via the Key module

### Chain Orchestration

- Create and manage LLM workflow chains
- Multi-step processing pipelines
- Conditional logic and branching
- Reusable chain templates
- Chain versioning and history

### Agent Management

- Build and deploy AI agents with specific capabilities
- Tool integration for enhanced agent functionality
- Agent memory and state management
- Agent conversation history
- Performance monitoring and metrics

### Prompt Management

- Create, store, and optimize prompts for LLMs
- Prompt templates with variable substitution
- Prompt versioning and A/B testing
- Prompt library with categorization
- Best practice recommendations

### Vector Storage

- Integration with vector databases
- Embedding generation and storage
- Semantic search capabilities
- Document chunking and processing
- Vector operation utilities

### Admin Interface

- Comprehensive UI for managing all LangChain components
- Dashboard with usage metrics and monitoring
- Configuration interface for providers and models
- Chain and agent builders
- Log viewer and debugging tools

## Use Cases

### Content Enhancement

Use AI agents to enhance content by suggesting improvements, generating summaries, extracting keywords, and identifying related content.

### Workflow Automation

Automate content workflows by using AI agents to review, classify, tag, and route content based on its characteristics.

### Personalization

Create personalized user experiences by using AI to analyze user behavior, preferences, and history to deliver targeted content and recommendations.

### Knowledge Management

Build intelligent knowledge bases by using RAG (Retrieval-Augmented Generation) to answer questions based on your site's content.

### Search Enhancement

Improve search functionality with semantic search capabilities, allowing users to find content based on meaning rather than just keywords.

## Requirements

- PHP 8.1 or higher
- Drupal 10.1 or 11.0
- Key module (for secure API key storage)

## Similar Modules

- **OpenAI API**: Focused specifically on OpenAI integration
- **AI Content Generator**: Focused on content generation only
- **AI Search**: Focused on AI-powered search capabilities

## Installation and Configuration

The module can be installed via Composer or manually. Once installed, navigate to the LangChain settings page to configure providers, models, and default parameters. See the README.md file for detailed installation and configuration instructions.

## Credits

This module was created by the Drupal community with contributions from various individuals and organizations.
