---
id: modules-development-langchain-INDEX
---
# LangChain Integration Documentation Index

## Stable Features (100% Built & Tested)

- **LangChain Agent Integration**: Native Drupal integration for LangChain agents and chains. [See details](ECA_CONDITIONS)
- **ECA Condition Plugins**: Use LangChain-specific ECA conditions for workflow automation. [See details](ECA_CONDITIONS)
- **Testing & Debugging Tools**: Tools for validating and debugging LangChain integrations. [See details](ECA_CONDITIONS.md#testing)
- **100% Code Coverage**: Comprehensive test coverage across all module components. [See details](testing/index)

## Release Readiness

- [x] All features above are fully implemented and tested
- [x] 100% test coverage (unit, kernel, functional)
- [x] All CI/CD checks pass
- [x] No deprecated or experimental APIs in this release
- [x] Documentation is up to date
- [x] Code quality tools implemented and passing

## Quick Start

1. `composer require bluefly/langchain`
2. `drush en langchain`
3. Configure LangChain agents and chains via Admin UI or config files
4. Use ECA conditions as documented in [ECA_CONDITIONS.md](ECA_CONDITIONS)

## Core Documentation

- [General Documentation](README) - Overview and getting started
- [Architecture Overview](ARCHITECTURE) - Detailed explanation of the module's architecture
- [Usage Examples](EXAMPLES) - Practical examples of how to use the module
- [Changelog](CHANGELOG) - History of changes and releases
- [Roadmap](ROADMAP) - Future development plans
- [Performance Benchmarks](BENCHMARKS) - Performance metrics for different components

## Technical Documentation

- [ECA Conditions](ECA_CONDITIONS) - Documentation for ECA conditions
- [Testing](testing) - General testing guidelines
- [Comprehensive Testing Guide](testing/index) - Detailed testing and coverage documentation
- [Test Coverage Status](TEST_COVERAGE_COMPLETE) - Current test coverage metrics
- [Controller Tests](controller-tests) - Information about controller testing
- [Plugin Tests](plugin-tests) - Information about plugin testing

## API Documentation

- [OpenAPI Specification](../langchain.openapi.yml) - Complete API reference

## Submodule Documentation

- [LangChain AI](../modules/langchain_ai/README) - Core AI provider integrations
- [LangChain ECA](../modules/langchain_eca/README) - Event-Condition-Action integration
- [LangChain RAG](../modules/langchain_rag/README) - Retrieval Augmented Generation capabilities
- [LangGraph](../modules/langchain_langgraph/README) - Advanced workflow capabilities
- [Langfuse Observability](../modules/langfuse_observability/README) - Monitoring and observability

## Development Tools

- [Code Quality Tools](../phpcs.xml.dist) - PHP_CodeSniffer configuration
- [Static Analysis](../phpstan.neon) - PHPStan configuration
- [Automated Refactoring](../rector.php) - Rector configuration

## Support & Contribution

- [Troubleshooting](ECA_CONDITIONS.md#troubleshooting)
- [Contributing](../CONTRIBUTING)
- [Issue Queue](https://www.drupal.org/project/issues/langchain) 
