---
id: modules-development-langchain-INSTALLATION
---
# Installation Guide for LangChain

This document provides detailed instructions for installing and configuring the LangChain module for Drupal.

## Requirements

Before installing this module, ensure your system meets the following requirements:

- PHP 8.1 or higher
- Drupal 10.1 or 11.0
- Required modules:
  - System
  - Key (for secure storage of API keys)
  - Field

## Recommended Modules

The following modules are recommended for a complete experience:

- ECA: For workflow automation
- Search API: For vector search capabilities
- Views: For custom admin interfaces
- Token: For enhanced prompt templating

## Installation Methods

### Using Composer (Recommended)

1. Add the Drupal package repository to your project's `composer.json` if it's not already there:

   ```json
   "repositories": [
       {
           "type": "composer",
           "url": "https://packages.drupal.org/8"
       }
   ]
   ```

2. Require the module using Composer:

   ```bash
   composer require drupal/langchain
   ```

3. Enable the module using Drush:

   ```bash
   drush en langchain
   ```

   Or enable it through the Drupal admin interface at `/admin/modules`.

### Manual Installation

1. Download the module from [drupal.org/project/langchain](https://www.drupal.org/project/langchain)
2. Extract the contents to your Drupal site's `modules/contrib` directory
3. Enable the module through the Drupal admin interface at `/admin/modules`

## Post-Installation Configuration

After installing the module, follow these steps to configure it:

### 1. Configure API Keys

1. Go to Administration > Configuration > System > Keys (`/admin/config/system/keys`)
2. Add a new key for each LLM provider you want to use:
   - For OpenAI: Create a key named `openai_api_key` with your OpenAI API key
   - For other providers: Create keys following the same pattern

### 2. Configure LangChain Settings

1. Navigate to Administration > Configuration > AI > LangChain Settings (`/admin/config/ai/langchain/settings`)
2. Configure general settings:
   - Default LLM provider
   - Default model for each provider
   - Default parameters (temperature, max tokens, etc.)
   - Advanced settings (cache lifetime, timeout, etc.)

### 3. Configure LLM Providers

1. Go to Administration > Configuration > AI > LangChain > Providers (`/admin/config/ai/langchain/providers`)
2. Add a new provider configuration:
   - Select provider type (OpenAI, HuggingFace, etc.)
   - Select the key to use for authentication
   - Configure API connection settings
   - Set default parameters

### 4. Configure Vector Storage (Optional)

If you want to use vector storage capabilities:

1. Go to Administration > Configuration > AI > LangChain > Vector Storage (`/admin/config/ai/langchain/vector-storage`)
2. Configure vector storage settings:
   - Storage backend (database, external service, etc.)
   - Default embedding model
   - Dimensionality and other parameters

## Provider-Specific Configuration

### OpenAI Configuration

For OpenAI integration:

1. Create an API key at [platform.openai.com](https://platform.openai.com/account/api-keys)
2. Add the key to the Key module as described above
3. Configure the OpenAI provider in the LangChain settings

### HuggingFace Configuration

For HuggingFace integration:

1. Create an API key at [huggingface.co/settings/tokens](https://huggingface.co/settings/tokens)
2. Add the key to the Key module as described above
3. Configure the HuggingFace provider in the LangChain settings
4. Specify the models you want to use

## Advanced Configuration

### Performance Optimization

For optimal performance, consider these settings:

```php
// In settings.php or similar
$settings['langchain_cache_lifetime'] = 3600; // Cache for 1 hour
$settings['langchain_parallel_requests'] = TRUE; // Enable parallel requests
$settings['langchain_timeout'] = 30; // Set timeout to 30 seconds
```

### High-Volume Sites

For sites with high traffic volume:

1. Enable result caching in the LangChain settings
2. Consider implementing a queueing system for AI requests
3. Use a CDN for static assets
4. Implement rate limiting for API requests

## Troubleshooting

### Common Issues

1. **API Connection Errors**:
   - Verify that your API keys are correct
   - Check that your server can connect to the API endpoints
   - Verify that you have sufficient quota/credits with the provider

2. **Performance Issues**:
   - Enable caching
   - Adjust timeout settings
   - Consider using smaller models for non-critical tasks

3. **Missing Dependencies**:
   - Make sure all required modules are installed and enabled
   - Check PHP extensions required by the module

### Getting Help

If you're still having issues, you can:

1. Check the [module issue queue](https://www.drupal.org/project/issues/langchain)
2. Ask in the Drupal community Slack or forums
3. Review the detailed documentation in the `/docs` directory

## Upgrading

When upgrading from previous versions, follow these steps:

1. Back up your site database
2. Update the module using Composer:
   ```bash
   composer update drupal/langchain
   ```
3. Run update.php or:
   ```bash
   drush updatedb
   ```
4. Clear caches:
   ```bash
   drush cache:rebuild
   ```
5. Check the release notes for breaking changes

## Next Steps

After installation and configuration, explore these resources to get started:

- [User Guide](USER_GUIDE): Learn how to use the module's features
- [Developer Guide](DEVELOPER_GUIDE): Learn how to extend and customize the module
- [API Reference](API_REFERENCE): Reference documentation for developers
- [Examples](../examples/): Example code for common use cases
