---
id: modules-development-langchain-testing-README
---
# LangChain Module Testing Documentation

This directory contains comprehensive documentation on testing the LangChain module, with a focus on achieving and maintaining 100% code coverage.

## Available Documentation

- [Testing & Coverage Guide](index) - Main documentation on testing and code coverage
- [Code Coverage Strategy](code-coverage) - Detailed strategy for achieving 100% code coverage
- [Coverage Exemptions](coverage-exemptions) - Documentation of code exempted from coverage requirements
- [Coverage History](coverage-history) - Historical coverage metrics and trends
- [Interpreting Coverage Reports](interpreting-coverage-reports) - Guide to understanding coverage reports

## Running Tests with Coverage

The simplest way to run tests with coverage is to use the provided script:

```bash
# Run all tests with HTML coverage report
./run-coverage-tests.sh

# Run only unit tests
./run-coverage-tests.sh -t unit

# Generate different report formats (html, text, clover, xml)
./run-coverage-tests.sh -f text
./run-coverage-tests.sh -f clover

# Show detailed coverage output
./run-coverage-tests.sh -f text -d
```

You can also use Composer scripts:

```bash
# Run all tests with HTML coverage report
composer test-coverage

# Run all tests with Clover XML report (for CI)
composer test-coverage-clover

# Display coverage report in terminal
composer test-coverage-text
```

## Coverage Requirements

The LangChain module requires:

- 100% line coverage
- 100% method coverage
- 100% class coverage
- ≥95% branch coverage

## Next Steps

After running the tests with coverage, review the HTML report at `coverage/html/index.html` to identify any remaining coverage gaps.
