---
title: Package Information
description: NPM package details for bfrfp
sidebar_position: 99
---

# Package Information

## Basic Info
- **Name**: `@bluefly/bfrfp`
- **Version**: `0.1.6`
- **Description**: AI-powered RFP automation platform that dramatically speeds up proposal creation
- **License**: MIT
- **Repository**: [GitLab](https://gitlab.bluefly.io/llm/bfrfp)

## Available Scripts
- **`npm run build`**: tsc
- **`npm run test`**: jest
- **`npm run test:watch`**: jest --watch
- **`npm run test:coverage`**: jest --coverage
- **`npm run test:integration`**: jest --testPathPattern=integration
- **`npm run test:unit`**: jest --testPathPattern=unit
- **`npm run test:ci`**: jest --ci --coverage --maxWorkers=2
- **`npm run lint`**: eslint 'src/**/*.ts'
- **`npm run lint:fix`**: eslint 'src/**/*.ts' --fix
- **`npm run typecheck`**: tsc --noEmit
- **`npm run start:api`**: npm run build && node dist/api/server.js
- **`npm run build-and-start`**: npm run build && node dist/api/server.js
- **`npm run dev`**: node scripts/dev-with-browser.js
- **`npm run dev:server-only`**: nodemon --exec "npm run build && node dist/api/server.js"
- **`npm run example`**: ts-node examples/quickstart.ts
- **`npm run clean`**: rm -rf dist coverage
- **`npm run ci`**: npm run lint && npm run typecheck && npm run test:ci
- **`npm run tdd:start`**: node scripts/tdd-helper.cjs start
- **`npm run tdd:coverage`**: node scripts/tdd-helper.cjs coverage
- **`npm run tdd:validate`**: node scripts/tdd-helper.cjs validate
- **`npm run tdd:generate`**: node scripts/tdd-helper.cjs generate
- **`npm run tdd:report`**: node scripts/tdd-helper.cjs report

## Dependencies (36)
- @huggingface/inference
- @langchain/anthropic
- @langchain/community
- @langchain/core
- @langchain/openai
- @pinecone-database/pinecone
- @types/compression
- @types/cors
- @types/express
- @types/lru-cache
- @types/multer
- @types/uuid
- @zilliz/milvus2-sdk-node
- chromadb
- chromadb-client
- clsx
- compression
- cors
- dotenv
- express
- express-rate-limit
- express-validator
- faiss-node
- helmet
- hnswlib-node
- langchain
- lru-cache
- multer
- openai
- pdf-parse
- redis
- tailwind-merge
- uuid
- winston
- ws
- zod

## Dev Dependencies (16)
- @types/jest
- @types/node
- @types/supertest
- @types/ws
- @typescript-eslint/eslint-plugin
- @typescript-eslint/parser
- eslint
- form-data
- jest
- node-fetch

... and 6 more
