# BFRFP - AI Content Generation - Troubleshooting

Common issues and solutions for BFRFP - AI Content Generation.

## Common Issues

### Startup Problems

**Service won't start**

```bash
# Check if port is available
netstat -tulpn | grep 3003

# Check environment variables
printenv | grep BFRFP

# Check logs
tail -f logs/app.log
```

**Dependencies not found**

```bash
# Verify all dependencies are running
docker-compose ps

# Restart dependencies
docker-compose restart
```

### Configuration Issues

**Environment variables not loaded**

```bash
# Check .env file exists
ls -la .env

# Verify syntax
cat .env | grep -v '^#' | grep '='
```

**Database connection failed**

```bash
# Test database connection
echo "No database configured"
```

### Performance Issues

**High memory usage**

- Check for memory leaks in application logs
- Monitor with `htop` or `docker stats`
- Review configuration for memory limits

**Slow response times**

- Enable debug logging
- Check database query performance
- Review network connectivity to dependencies

## Debug Mode

Enable debug logging:

```bash
LOG_LEVEL=debug npm start
```

## Health Checks

```bash
# Basic health check
curl http://localhost:3003/health

# Detailed diagnostics
curl http://localhost:3003/diagnostics
```

## Getting Help

- **Issues**: [https://gitlab.bluefly.io/ecosystem/bfrfp/issues](https://gitlab.bluefly.io/ecosystem/bfrfp/issues)
- **Documentation**: [Platform Hub](https://gitlab.bluefly.io/ecosystem/bfdocs)
- **Logs**: Check application and system logs for detailed error messages

---

*Part of the [BFRFP - AI Content Generation](../index.md) documentation.*
