# LLM Platform SDK Documentation

TypeScript SDK for the LLM Platform API.

## Quick Start

```typescript
import [LLMPlatformClient] from '@llm/platform-sdk';

const client = new LLMPlatformClient({
  baseURL: 'https://api.llm-platform.dev',
  apiKey: process.env.LLM_API_KEY,
});

// Use the client
const models = await client.models.list();
```

## Documentation

- [API Reference](api.md)
- [Configuration](configuration.md)
- [Examples](examples.md)
- [Integration Guide](integration.md)
- [Error Handling](error-handling.md)
- [Resilience Patterns](resilience.md)
- [Resilient Caching](resilient-caching.md)
- [Changelog](changelog.md)

## Architecture

The llm-gateway-sdk serves as the TypeScript SDK for all LLM Platform services:

```
frontend → llm-gateway-sdk → LLM API
cli → llm-gateway-sdk → LLM API
services → llm-gateway-sdk → LLM API
```

Key features:

- Type-safe API interactions
- Automatic authentication handling
- Built-in caching and retry logic
- Support for both REST and GraphQL endpoints- [SHARED_UTILITIES_MIGRATION.md](shared_utilities_migration.md)
