# BFAPI Request Routing System

The BFAPI Request Routing System manages request routing across services using ML-based strategies, context-aware decisions, and performance monitoring.

## Core Features

- **Request Analysis**: Analyzes request patterns and content
- **Load Balancing**: Distributes requests based on service capacity
- **Performance Monitoring**: Tracks service metrics and health
- **Metrics**: Provides service metrics and recommendations
- **Error Handling**: Manages routing failures and retries

## Routing Metrics

The system provides the following metrics:

- Request latency
- Service response times
- Error rates
- Resource utilization
- Cache hit rates

## Request Processing Flow

1. Request received
2. Context analysis
3. Service selection
4. Request routing
5. Response handling
6. Metrics collection

## Implementation Benefits

- Reduced latency
- Improved reliability
- Better resource utilization
- Automated failover
- Real-time monitoring

## Configuration

```yaml
routing:
  strategy: ml-based
  timeout: 5000
  retries: 3
  circuitBreaker:
    threshold: 0.8
    resetTimeout: 30000
```

## Monitoring

```bash
# Check routing status
llmcli routing:status

# View routing metrics
llmcli routing:metrics

# Analyze routing patterns
llmcli routing:analyze
```

## Policy Framework

The system supports custom routing rules through a policy framework:

```typescript
interface RoutingPolicy {
  name: string;
  conditions: Condition[];
  actions: Action[];
  priority: number;
}
```

## Related Documentation

- [API Documentation](../api/README.md)
- [Monitoring Guide](../monitoring/README.md)
- [Performance Guide](../performance/README.md)

## Support Resources

- [GitLab Issues](https://gitlab.com/blueflyio/internal-projects/llm/bfapi/-/issues)
- [CI/CD Pipeline](https://gitlab.com/blueflyio/internal-projects/llm/bfapi/-/pipelines)
- [Documentation](https://gitlab.com/blueflyio/internal-projects/llm/bfapi/-/wikis)