# Guide Title

Brief overview of what this guide covers and who it's for. This section should be 1-3 paragraphs that clearly explain the purpose of the guide and what the reader will learn.

## Table of Contents

- [Prerequisites](#prerequisites)
- [Section 1](#section-1)
- [Section 2](#section-2)
- [Section 3](#section-3)
- [Examples](#examples)
- [Troubleshooting](#troubleshooting)
- [See Also](#see-also)

## Prerequisites

What the reader needs before starting:

- Requirement 1
- Requirement 2
- Requirement 3

## Section 1

Content for section 1. This should include a clear explanation of the concept, feature, or task being described. Use code examples, diagrams, and screenshots where appropriate.

```typescript
// Example code with comments
import [McpClient] from '@llm-mcp/client';

// Initialize client
const client = new McpClient({
  url: 'http://localhost:3001',
  apiKey: 'your-api-key'
});
```

## Section 2

Content for section 2. Break down complex topics into digestible chunks with clear headings and subheadings.

### Subsection 2.1

More detailed information about a specific aspect of the topic.

> **Note:** Use blockquotes for important notes, warnings, or tips.

### Subsection 2.2

Additional information with examples.

## Section 3

Content for section 3. Use tables for structured data if applicable.

| Option | Type | Default | Description |
|--------|------|---------|-------------|
| `option1` | string | `"default"` | Description of option1 |
| `option2` | number | `42` | Description of option2 |
| `option3` | boolean | `false` | Description of option3 |

## Examples

Provide practical examples of the concepts discussed in the guide. Each example should be self-contained and include:

### Example 1: Basic Usage

This example demonstrates a basic use case.

```typescript
import [McpClient] from '@llm-mcp/client';

async function basicExample() {
  // Create client
  const client = new McpClient({
    url: 'http://localhost:3001',
    apiKey: 'your-api-key'
  });
  
  // Use the client
  const result = await client.someOperation({
    param1: 'value1',
    param2: 'value2'
  });
  
  console.log('Result:', result);
}

basicExample().catch(console.error);
```

Key points about this example:
- Creates a basic client
- Performs a simple operation
- Handles the result

### Example 2: Advanced Usage

This example demonstrates a more advanced use case.

```typescript
// Advanced example code
```

## Troubleshooting

Common issues and their solutions.

### Issue 1: Problem Description

Symptom: What the user will observe when encountering this issue.

Solution: Steps to resolve the issue.

### Issue 2: Another Problem

Symptom: Description of symptoms.

Solution: Steps to resolve the issue.

## See Also

- [Related Guide 1](path/to/related-guide-1.md) - Brief description of related guide
- [Related Guide 2](path/to/related-guide-2.md) - Brief description of related guide
- [API Reference](path/to/api-reference.md) - API documentation for features covered in this guide