# acui Enhancement Plan: Dual Usage as TypeScript Dashboards and Drupal Single Directory Components (SDC)

## 1. Overview of Drupal Single Directory Components (SDC)

- SDC allows placing all component files (JS/TSX, CSS, templates) in a single directory.
- Drupal consumes these components as asset libraries and Twig templates.
- Supports modern frontend frameworks like React.
- Requires build tooling to produce Drupal-compatible assets.

## 2. Current acui Component Structure

- React functional components written in TypeScript.
- Components organized in subdirectories under `acui/src/components`.
- Example: `UnifiedDashboard.tsx` composes smaller components.

## 3. Proposed Folder Structure and Build Tooling

- Organize each component as an SDC with its own directory containing TSX, CSS, and optional Twig files.
- Use a monorepo or shared source directory for components to be used in both standalone dashboards and Drupal.
- Configure build tooling (Webpack, Vite) to output Drupal-compatible JS/CSS bundles per component.
- Generate Drupal `libraries.yml` entries automatically or maintain manually.

## 4. Drupal Integration

- Define asset libraries in `LLM Platform_llm_platform.libraries.yml` or a dedicated module.
- Use Twig templates to render components server-side or as placeholders.
- Attach asset libraries in Drupal render arrays or controllers.
- Support Drupal behaviors if needed for JS initialization.

## 5. TypeScript and Module Resolution

- Configure `tsconfig.json` paths for shared components.
- Ensure typings are compatible with both standalone and Drupal environments.
- Use environment variables or build flags to toggle Drupal-specific code.

## 6. Development and Deployment Workflow

- Develop components in isolation with hot-reloading.
- Build and package components for Drupal consumption.
- Deploy Drupal module with updated libraries and templates.
- Automate validation and testing for both usage modes.

## 7. Architecture Diagram

```mermaid
graph TD
  A[acui Components Source] --> B[Build Tooling]
  B --> C[Standalone Dashboard Bundles]
  B --> D[Drupal SDC Bundles]
  D --> E[Drupal Asset Libraries]
  E --> F[Drupal Render Arrays / Twig Templates]
  C --> G[Standalone React Dashboard]
  F --> H[Drupal Themed Pages]
```

---

Please confirm if you would like me to assist with implementing this plan or generating any specific configuration or code.
