# LLM Platform Install - Quick Reference

## Essential Commands

### Basic Installation
```bash
llmcli llm platform:install --working-dir ./my-project --project-name my-app
```

### Enterprise Setup
```bash
llmcli llm platform:install --template enterprise --working-dir ./enterprise-app
```

### Development Setup
```bash
llmcli llm platform:install --template development --working-dir ./dev-app
```

### Test Configuration (Dry Run)
```bash
llmcli llm platform:install [options] --dry-run
```

## Quick Options Reference

### Must-Have Options
| Option | Purpose | Example |
|--------|---------|---------|
| `--working-dir` | Installation location | `--working-dir ./my-project` |
| `--project-name` | Project identifier | `--project-name my-llm-app` |

### AI Providers
| Provider | Command | Use Case |
|----------|---------|----------|
| OpenAI | `--provider openai` | Commercial GPT models |
| Anthropic | `--provider anthropic` | Claude models |
| Ollama | `--provider ollama` | Local models |
| Hugging Face | `--provider huggingface` | Open source models |

### Vector Databases
| Database | Command | Use Case |
|----------|---------|----------|
| SQLite | `--vector-db sqlite` | Development/small scale |
| PostgreSQL | `--vector-db postgres` | Production/self-hosted |
| Weaviate | `--vector-db weaviate` | Full-featured vector DB |
| Pinecone | `--vector-db pinecone` | Managed cloud service |

### Templates
| Template | Command | Purpose |
|----------|---------|---------|
| Enterprise | `--template enterprise` | Full production setup |
| Development | `--template development` | Developer-friendly |
| Minimal | `--template minimal` | Basic features only |

### Security Levels
| Level | Command | Use Case |
|-------|---------|----------|
| Basic | `--security-level basic` | Development |
| Standard | `--security-level standard` | Most applications |
| Maximum | `--security-level maximum` | High-security environments |

## Common Combinations

### Local Development with AI
```bash
llmcli llm platform:install \
  --working-dir ./dev-project \
  --provider ollama \
  --ai-models "llama2,mistral" \
  --vector-db sqlite \
  --template development
```

### Production with OpenAI
```bash
llmcli llm platform:install \
  --working-dir ./prod-project \
  --provider openai \
  --ai-models "gpt-4,gpt-3.5-turbo" \
  --vector-db weaviate \
  --template enterprise \
  --security-level maximum
```

### Multi-Provider Setup
```bash
llmcli llm platform:install \
  --working-dir ./multi-project \
  --provider openai \
  --suggest-providers "anthropic,ollama" \
  --ai-models "gpt-4,claude-3-opus,llama2" \
  --vector-db postgres
```

### Cloud Services
```bash
llmcli llm platform:install \
  --working-dir ./cloud-project \
  --provider openai \
  --vector-db pinecone \
  --embedding-models "text-embedding-ada-002" \
  --security-level maximum
```

## DDEV Services Cheat Sheet

### Database
- `mariadb` - MariaDB
- `postgres` - PostgreSQL
- `mysql` - MySQL

### Cache
- `redis` - Redis cache
- `memcached` - Memcached

### Search
- `elasticsearch` - Elasticsearch
- `opensearch` - OpenSearch

### Vector DBs
- `weaviate` - Weaviate
- `milvus` - Milvus
- `qdrant` - Qdrant

### Utilities
- `mailpit` - Email testing
- `minio` - Object storage

Example:
```bash
--ddev-services "postgres,redis,elasticsearch,weaviate"
```

## Feature Flags Quick List

| Flag | Purpose |
|------|---------|
| `--with-vector-db` | Enable vector database |
| `--with-ai-services` | AI service integration |
| `--with-secure` | Security hardening |
| `--with-automated-testing` | Testing setup |
| `--ui-wizard` | Interactive setup |
| `--env-detect` | Auto-detect environment |

## Troubleshooting Quick Fixes

### Error: Missing working directory
**Fix:** Add `--working-dir ./your-project`

### Error: Service conflicts
**Fix:** Use `--ddev-name unique-name`

### Error: Unknown option
**Fix:** Check option spelling, use `--help` for list

### Test before install
**Always use:** `--dry-run` to verify configuration

## Get Help

```bash
# See all options
llmcli llm platform:install --help

# Test configuration
llmcli llm platform:install [options] --dry-run

# Check LLMCLI version
llmcli --version
```