# Secure Authentication Module

## Overview
The Secure Authentication module provides enterprise-grade authentication and access management capabilities for Drupal sites operating in regulated environments. It implements rigorous security controls to meet the requirements of multiple compliance frameworks.

## Key Features

### Authentication Controls
- Advanced password policy management
- Multi-factor authentication (MFA) integration
- Login attempt limitations and throttling
- Session timeout and management
- Credentials rotation and history enforcement

### Access Control
- Fine-grained role-based access control (RBAC)
- Least privilege enforcement
- Separation of duties
- IP-based access restrictions
- Time-based access windows

### Security Validation
- Automated security control validation
- Compliance checking against multiple frameworks
- Security posture reporting
- Remediation recommendations

## Compliance Framework Mappings

### NIST 800-53 / FedRAMP
- IA-2: Identification and Authentication (Organizational Users)
- IA-5: Authenticator Management
- IA-6: Authenticator Feedback 
- IA-7: Cryptographic Module Authentication
- AC-2: Account Management
- AC-3: Access Enforcement
- AC-7: Unsuccessful Logon Attempts
- AC-11: Session Lock

### HIPAA
- 164.308(a)(5)(ii)(D): Password Management
- 164.312(a)(1): Access Control
- 164.312(d): Person or Entity Authentication

### PCI DSS 4.0
- Requirement 8.2: User identification and authentication
- Requirement 8.3: Strong authentication for users and administrators
- Requirement 8.3.6: Password/passphrase requirements
- Requirement 8.3.7: Multi-factor authentication

### ISO 27001:2022
- A.5.15: Access control
- A.5.16: Identity management
- A.5.17: Authentication information
- A.5.18: Access rights
- A.9.4.3: Password management system

## Installation and Prerequisites

### Required Modules
```bash
# Core dependency
drush en secure_core -y

# Install secure_auth
drush en secure_auth -y
```

### Recommended Modules
For full compliance capabilities, install these contributed modules:
```bash
# Password policy modules
composer require drupal/password_policy
drush en password_policy password_policy_length password_policy_character_types password_policy_history password_policy_username -y

# Login security
composer require drupal/login_security
drush en login_security -y

# Two-factor authentication
composer require drupal/tfa
drush en tfa -y
```

## Configuration and Administration

### Password Policy Configuration
1. Navigate to Administration → Configuration → Security → Password Policy
2. Create policies that align with your compliance requirements
3. Assign policies to appropriate roles

### Authentication Settings
1. Navigate to Administration → Configuration → Security → Secure Authentication
2. Configure authentication requirements:
   - Failed login attempt thresholds
   - Session timeout periods
   - MFA requirements

### Security Control Validation
Run validation checks using Drush:
```bash
# Validate authentication controls
drush secure:auth:validate

# Apply recommended configurations
drush secure:auth:apply
```

## Integration with Compliance Reporting
This module integrates with the parent Secure Drupal framework to generate comprehensive compliance reports that map all implemented controls to their corresponding compliance requirements.

## Contributing
- Report security issues to [security@bluefly.io](mailto:security@bluefly.io)
- Submit pull requests to enhance control coverage
- Suggest additional compliance mappings 