# Drupal Coding Standards Policy (TDDAI)

## Required Policy for All Drupal Code

All code—including Drush commands, modules, and themes—**must strictly adhere to the official Drupal coding standards and "Drupal way" best practices**. This includes:

- 2-space indentation
- PSR-4 autoloading
- Dependency injection
- Configuration management
- Use of core/contrib APIs
- Secure and accessible code (WCAG 2.2 AA)
- Comprehensive documentation (PHPDoc, README)
- Automated testing (unit, kernel, functional)

**No code may be merged or executed unless it passes all Drupal coding standards and best practices checks.**

---

## Enforcement

This policy is enforced by TDDAI for all code tagged as `drupal`, `drush`, `drupal-module`, `drupal-theme`, or `drupal-command`. It is marked as `required` and will block merges or execution if not satisfied.

---

## Usage

To validate your codebase for Drupal standards compliance, run:

```bash
tddai validate project --strict
```

This will:
- Check all code for Drupal coding standards (using PHPCS, Coder, etc.)
- Enforce dependency injection, configuration management, and other best practices
- Block non-compliant code from merging or running

---

## References

- [Drupal Coding Standards](https://www.drupal.org/docs/develop/standards)
- [PHP Coding Standards](https://www.drupal.org/node/318) 