# Final Setup Instructions for ReelCode

This document provides instructions for the final setup of the ReelCode project and the relocation of the original projects.

## 1. Complete Project Setup

```bash
# Navigate to the ReelCode project directory
cd ./tddai

# Install dependencies
npm install

# Build the project
npm run build

# Verify the build
npm run typecheck
npm run lint

# Run initial tests (once implemented)
# npm test
```

## 2. Relocate Original Projects

Once you're satisfied with the ReelCode implementation and have verified that all key functionality has been migrated, follow these steps to relocate the original projects:

```bash
# Make sure the __DELETE_LATER directory exists
mkdir -p ./__DELETE_LATER

# Move the original CodeOwl project
mv ./codeowl ./__DELETE_LATER/

# Move the original AI Coding Assistant project
mv ./ai-coding-assistant ./__DELETE_LATER/

# Create relocation markers
echo "# Project relocated to ReelCode on $(date)" > ./__DELETE_LATER/codeowl/RELOCATED.md
echo "# Project relocated to ReelCode on $(date)" > ./__DELETE_LATER/ai-coding-assistant/RELOCATED.md
```

## 3. Setup Local Development Environment

### Link for Local Development

```bash
# Navigate to the ReelCode project directory
cd ./tddai

# Link the package globally for development
npm link

# Verify the link
tddai --version
```

### Create a Test Project for Verification

```bash
# Create a test project
mkdir -p ~/test-tddai
cd ~/test-tddai
npm init -y

# Create a simple configuration file
cat > .tddairc.yaml << EOF
analysis:
  maxFileSize: 1000000
  ignorePatterns:
    - "node_modules/**"
    - "dist/**"

testing:
  framework: "jest"
  coverage:
    statements: 90
    branches: 80
    functions: 90
    lines: 90
EOF

# Create a simple test file
mkdir -p src
cat > src/example.js << EOF
function add(a, b) {
  return a + b;
}

function subtract(a, b) {
  return a - b;
}

module.exports = { add, subtract };
EOF

# Test ReelCode on this project
tddai analyze .
```

## 4. Documentation Verification

Ensure all documentation is accurate and complete:

- [ ] README.md
- [ ] MIGRATION.md
- [ ] IMPLEMENTATION_PLAN.md
- [ ] API documentation
- [ ] CLI documentation
- [ ] Configuration guide

## 5. Publish Plan

Once the project is ready for initial release:

```bash
# Set the version if needed
npm version patch

# Publish to npm
npm publish --access public

# Create a git tag
git tag -a v1.0.0 -m "Initial release"
git push --tags
```

## 6. Cleanup (After Successful Migration)

This step should only be performed after ensuring the migration is complete and successful:

```bash
# After a reasonable time (e.g., 3 months), archive or delete the old projects
# cd ./__DELETE_LATER
# tar -czvf codeowl-archive.tar.gz codeowl
# tar -czvf ai-coding-assistant-archive.tar.gz ai-coding-assistant
# rm -rf codeowl ai-coding-assistant
```

## 7. Final Verification Checklist

- [ ] Project builds successfully
- [ ] All planned functionality is implemented
- [ ] Tests pass with adequate coverage
- [ ] Documentation is complete and accurate
- [ ] CLI commands work as expected
- [ ] Original projects relocated to __DELETE_LATER
- [ ] Marker files created in relocated projects

## 8. Next Steps for Further Development

- [ ] Implement additional ML models
- [ ] Enhance visualization capabilities
- [ ] Add support for more programming languages
- [ ] Implement IDE integrations
- [ ] Create comprehensive examples
- [ ] Add tutorial content to documentation