# ReelCode Project Relocation Instructions

This document provides instructions for relocating the original projects (CodeOwl and AI Coding Assistant) to the __DELETE_LATER folder after the ReelCode migration is complete.

## Prerequisites

Before relocating the original projects, ensure that:

1. All key functionality has been migrated to ReelCode
2. The ReelCode project structure is complete
3. Core components have been identified and moved
4. Migration documentation is complete

## Relocation Process

### Step 1: Create a backup (Optional but recommended)

```bash
# Create a timestamped backup of both projects
mkdir -p ./backups/$(date +%Y-%m-%d)
cp -r ./codeowl ./backups/$(date +%Y-%m-%d)/
cp -r ./ai-coding-assistant ./backups/$(date +%Y-%m-%d)/
```

### Step 2: Move projects to __DELETE_LATER folder

```bash
# Move the entire projects to the __DELETE_LATER folder
mv ./codeowl ./__DELETE_LATER/codeowl
mv ./ai-coding-assistant ./__DELETE_LATER/ai-coding-assistant
```

### Step 3: Create relocation marker files

Create a file in each relocated project directory to indicate when and why they were moved:

```bash
# Create a marker file in each relocated project
cat > ./__DELETE_LATER/codeowl/RELOCATED.md << EOF
# Project Relocated

This project (CodeOwl) has been migrated to the new ReelCode project.

- **Date of Relocation**: $(date +%Y-%m-%d)
- **Reason**: Merged with AI Coding Assistant to form ReelCode
- **New Location**: ./tddai
EOF

cat > ./__DELETE_LATER/ai-coding-assistant/RELOCATED.md << EOF
# Project Relocated

This project (AI Coding Assistant) has been migrated to the new ReelCode project.

- **Date of Relocation**: $(date +%Y-%m-%d)
- **Reason**: Merged with CodeOwl to form ReelCode
- **New Location**: ./tddai
EOF
```

### Step 4: Create migration index file

Create a file in the __DELETE_LATER directory to track all relocated projects:

```bash
# Create or update the index file
cat > ./__DELETE_LATER/MIGRATION_INDEX.md << EOF
# Migration Index

This file tracks projects that have been migrated or relocated.

## ReelCode Migration ($(date +%Y-%m-%d))

The following projects were merged to create ReelCode:

1. **CodeOwl** - Moved to __DELETE_LATER/codeowl
   - Original Location: ./codeowl
   - New Project: ReelCode (./tddai)

2. **AI Coding Assistant** - Moved to __DELETE_LATER/ai-coding-assistant
   - Original Location: ./ai-coding-assistant
   - New Project: ReelCode (./tddai)

All functionality from both projects has been preserved in the new ReelCode project.
EOF
```

## Verification Checklist

Before considering the relocation complete, verify:

- [ ] All key functionality has been migrated to ReelCode
- [ ] Documentation reflects the merged state
- [ ] ReelCode project can be built and run successfully
- [ ] Tests pass in the new ReelCode project
- [ ] Migration guide is complete for users of both tools
- [ ] Marker files are in place in the relocated directories
- [ ] Migration index is updated

## Recovery Plan

If issues are discovered after relocation:

1. Refer to the original code in the __DELETE_LATER directory
2. Consult the backup if necessary
3. Update ReelCode to fix any issues or missing functionality
4. Document the changes in the migration notes

## Next Steps After Relocation

1. Run a full build and test of ReelCode
2. Update any documentation references to the old projects
3. Consider archiving the __DELETE_LATER directory contents after a suitable waiting period (e.g., 3 months)
4. Notify users of the completed migration