# TDDAI v3.0 - Simple TDD Framework

A simplified Test-Driven Development framework following Drupal's "keep it simple" philosophy.

## Installation

```bash
npm install @bluefly/tddai
```

## Quick Start

```bash
# Setup TDD for your project
tddai setup --type node --framework jest

# Generate tests for a file
tddai generate src/myfile.js

# Run tests
tddai test

# Check project status
tddai status
```

## Commands

### Core Commands
- `tddai test` - Run tests
- `tddai generate <file>` - Generate tests
- `tddai analyze [path]` - Analyze code quality
- `tddai setup` - Setup TDD framework
- `tddai validate [path]` - Validate TDD compliance

### Advanced Commands
- `tddai migrate <from> <to>` - Migrate test frameworks
- `tddai drupal <action> [module]` - Drupal operations
- `tddai ai <action> [target]` - AI-powered operations
- `tddai config <action>` - Manage configuration
- `tddai status [path]` - Show TDD status

## Configuration

Create `tddai.yml` in your project root:

```yaml
framework: jest
coverage: 95
ai:
  provider: ollama
  model: llama2
```

## Examples

### Generate Tests with AI
```bash
tddai generate src/calculator.js --ai --function add
```

### Analyze Code Quality
```bash
tddai analyze src/utils.js --ai
```

### Drupal Module Testing
```bash
tddai drupal setup modules/my_module
tddai drupal test modules/my_module
```

## AI Providers

TDDAI supports multiple AI providers:
- **Ollama** (local, recommended)
- **OpenAI** (requires API key)
- **Anthropic** (requires API key)

Configure in `tddai.yml` or use `--provider` flag.

## Project Types

- `node` - Node.js projects
- `react` - React applications
- `drupal` - Drupal modules
- `php` - PHP projects

## Test Frameworks

- `jest` - JavaScript/TypeScript (default)
- `phpunit` - PHP/Drupal
- `vitest` - Modern JavaScript
- `mocha` - Legacy JavaScript

## Architecture

TDDAI v3.0 follows Drupal's architectural principles:

- **Simple Task Runner** - Direct async execution
- **Single AI Provider** - No complex abstractions
- **Clear Commands** - Focused, verb-based CLI
- **One Config File** - Simple YAML configuration
- **Minimal Dependencies** - Only essential packages

## Drupal Integration

TDDAI integrates naturally with Drupal projects:

```bash
# Setup Drupal module testing
tddai drupal setup web/modules/custom/my_module

# Run PHPUnit tests
tddai test --drupal

# Validate Drupal coding standards
tddai validate --drupal
```

## Migration

Migrate from other frameworks:

```bash
# From Mocha to Jest
tddai migrate mocha jest

# From PHPUnit 8 to PHPUnit 10
tddai migrate phpunit8 phpunit10
```

## Development

```bash
# Clone repository
git clone https://github.com/bluefly/tddai.git
cd tddai

# Install dependencies
npm install

# Build
npm run build

# Test
npm test
```

## License

MIT