const rateLimit = require('express-rate-limit');
const { rateLimit: rateLimitConfig } = require('../config/auth');
const logger = require('../utils/logger');

// Standard rate limiter for authenticated endpoints
const standardLimiter = rateLimit({
  windowMs: rateLimitConfig.standardWindow,
  max: rateLimitConfig.standardMax,
  standardHeaders: true,
  legacyHeaders: false,
  keyGenerator: (req) => req.user ? req.user.id.toString() : req.ip,
  handler: (req, res) => {
    logger.warn(`Rate limit exceeded for ${req.user ? `user ${req.user.id}` : `IP ${req.ip}`}`);
    return res.status(429).json({
      error: 'rate_limit_exceeded',
      message: 'Too many requests, please try again later',
      retryAfter: Math.ceil(rateLimitConfig.standardWindow / 1000)
    });
  }
});

// Rate limiter for authentication endpoints
const authLimiter = rateLimit({
  windowMs: rateLimitConfig.authWindow,
  max: rateLimitConfig.authMax,
  standardHeaders: true,
  legacyHeaders: false,
  keyGenerator: (req) => req.ip,
  handler: (req, res) => {
    logger.warn(`Authentication rate limit exceeded for IP ${req.ip}`);
    return res.status(429).json({
      error: 'rate_limit_exceeded',
      message: 'Too many authentication attempts, please try again later',
      retryAfter: Math.ceil(rateLimitConfig.authWindow / 1000)
    });
  }
});

// Rate limiter for bulk operations
const bulkLimiter = rateLimit({
  windowMs: rateLimitConfig.bulkWindow,
  max: rateLimitConfig.bulkMax,
  standardHeaders: true,
  legacyHeaders: false,
  keyGenerator: (req) => req.user ? req.user.id.toString() : req.ip,
  handler: (req, res) => {
    logger.warn(`Bulk operation rate limit exceeded for ${req.user ? `user ${req.user.id}` : `IP ${req.ip}`}`);
    return res.status(429).json({
      error: 'rate_limit_exceeded',
      message: 'Too many bulk operations, please try again later',
      retryAfter: Math.ceil(rateLimitConfig.bulkWindow / 1000)
    });
  }
});

module.exports = {
  standardLimiter,
  authLimiter,
  bulkLimiter
};