#!/usr/bin/env node

/**
 * Script to test @bluefly/shared integration
 */

// Dynamic import is used to ensure ES modules compatibility
async function testSharedUtilities() {
  try {
    const sharedModule = await import('@bluefly/shared');
    console.log('Successfully imported @bluefly/shared');
    console.log('- Available exports:', Object.keys(sharedModule));
    
    // Test specific modules
    const configModule = await import('@bluefly/shared/config/index.js');
    console.log('\nConfig module:');
    console.log('- Available exports:', Object.keys(configModule));
    
    const loggerModule = await import('@bluefly/shared/logger/index.js');
    console.log('\nLogger module:');
    console.log('- Available exports:', Object.keys(loggerModule));
    
    const errorsModule = await import('@bluefly/shared/errors/index.js');
    console.log('\nErrors module:');
    console.log('- Available exports:', Object.keys(errorsModule));
    
    const utilsModule = await import('@bluefly/shared/utils/index.js');
    console.log('\nUtils module:');
    console.log('- Available exports:', Object.keys(utilsModule));
    
    console.log('\n✅ @bluefly/shared integration test passed!');
  } catch (error) {
    console.error('\n❌ Error testing @bluefly/shared integration:');
    console.error(error);
    process.exit(1);
  }
}

testSharedUtilities();